@@ -1,10 +1,11 @@
 import unittest
+
 import pytest
 
-import rx
-from rx.internal.exceptions import SequenceContainsNoElementsError
-from rx import operators as ops
-from rx.testing import ReactiveTest
+import reactivex
+from reactivex import operators as ops
+from reactivex.internal.exceptions import SequenceContainsNoElementsError
+from reactivex.testing import ReactiveTest
 
 on_next = ReactiveTest.on_next
 on_completed = ReactiveTest.on_completed
@@ -25,35 +26,34 @@ def _raise(ex):
 
 
 class TestBlocking(unittest.TestCase):
-
     def test_run_empty(self):
         with pytest.raises(SequenceContainsNoElementsError):
-            rx.empty().run()
+            reactivex.empty().run()
 
     def test_run_error(self):
         with pytest.raises(RxException):
-            rx.throw(RxException()).run()
+            reactivex.throw(RxException()).run()
 
     def test_run_just(self):
-        result = rx.just(42).run()
+        result = reactivex.just(42).run()
         assert result == 42
 
     def test_run_range(self):
-        result = rx.range(42).run()
+        result = reactivex.range(42).run()
         assert result == 41
 
     def test_run_range_to_iterable(self):
-        result = rx.range(42).pipe(ops.to_iterable()).run()
+        result = reactivex.range(42).pipe(ops.to_iterable()).run()
         assert list(result) == list(range(42))
 
     def test_run_from(self):
-        result = rx.from_([1, 2, 3]).run()
+        result = reactivex.from_([1, 2, 3]).run()
         assert result == 3
 
     def test_run_from_first(self):
-        result = rx.from_([1, 2, 3]).pipe(ops.first()).run()
+        result = reactivex.from_([1, 2, 3]).pipe(ops.first()).run()
         assert result == 1
 
     def test_run_of(self):
-        result = rx.of(1, 2, 3).run()
+        result = reactivex.of(1, 2, 3).run()
         assert result == 3
