@@ -1,9 +1,9 @@
 import unittest
 from datetime import timedelta
 
-import rx
-from rx import operators as ops
-from rx.testing import TestScheduler, ReactiveTest
+import reactivex
+from reactivex import operators as ops
+from reactivex.testing import ReactiveTest, TestScheduler
 
 on_next = ReactiveTest.on_next
 on_completed = ReactiveTest.on_completed
@@ -23,7 +23,7 @@ class TimeSpan(object):
 class TimeInterval(object):
     def __init__(self, value, interval):
         if isinstance(interval, timedelta):
-            interval = int(interval.microseconds/1000)
+            interval = int(interval.microseconds / 1000)
 
         self.value = value
         self.interval = interval
@@ -45,7 +45,6 @@ def new_timer(l, t, scheduler):
 
 
 class TestGroup_join(unittest.TestCase):
-
     def test_group_join_op_normal_i(self):
         scheduler = TestScheduler()
 
@@ -60,7 +59,7 @@ class TestGroup_join(unittest.TestCase):
             on_next(710, TimeInterval(7, 280)),
             on_next(720, TimeInterval(8, 100)),
             on_next(830, TimeInterval(9, 10)),
-            on_completed(900)
+            on_completed(900),
         )
 
         ys = scheduler.create_hot_observable(
@@ -74,7 +73,7 @@ class TestGroup_join(unittest.TestCase):
             on_next(712, TimeInterval("man", 10)),
             on_next(722, TimeInterval("rat", 200)),
             on_next(732, TimeInterval("wig", 5)),
-            on_completed(800)
+            on_completed(800),
         )
 
         xsd = []
@@ -83,16 +82,16 @@ class TestGroup_join(unittest.TestCase):
         def create():
             def mapper(x_yy):
                 x, yy = x_yy
-                return yy.pipe(ops.map(lambda y: '{}{}'.format(x.value, y.value)))
+                return yy.pipe(ops.map(lambda y: "{}{}".format(x.value, y.value)))
 
             return xs.pipe(
                 ops.group_join(
                     ys,
                     lambda x: new_timer(xsd, x.interval, scheduler),
                     lambda y: new_timer(ysd, y.interval, scheduler),
-                    ),
+                ),
                 ops.flat_map(mapper),
-                )
+            )
 
         res = scheduler.start(create=create)
 
@@ -118,13 +117,12 @@ class TestGroup_join(unittest.TestCase):
             on_next(732, "7wig"),
             on_next(732, "8wig"),
             on_next(830, "9rat"),
-            on_completed(990)]
+            on_completed(990),
+        ]
 
-        assert xs.subscriptions == [
-            subscribe(200, 900)]
+        assert xs.subscriptions == [subscribe(200, 900)]
 
-        assert ys.subscriptions == [
-            subscribe(200, 800)]
+        assert ys.subscriptions == [subscribe(200, 800)]
 
     def test_group_join_op_normal_ii(self):
         scheduler = TestScheduler()
@@ -139,7 +137,7 @@ class TestGroup_join(unittest.TestCase):
             on_next(700, TimeInterval(6, 25)),
             on_next(710, TimeInterval(7, 200)),
             on_next(720, TimeInterval(8, 100)),
-            on_completed(721)
+            on_completed(721),
         )
 
         ys = scheduler.create_hot_observable(
@@ -153,7 +151,7 @@ class TestGroup_join(unittest.TestCase):
             on_next(712, TimeInterval("man", (10))),
             on_next(722, TimeInterval("rat", (200))),
             on_next(732, TimeInterval("wig", (5))),
-            on_completed(990)
+            on_completed(990),
         )
 
         xsd = []
@@ -162,16 +160,16 @@ class TestGroup_join(unittest.TestCase):
         def create():
             def mapper(x_yy):
                 x, yy = x_yy
-                return yy.pipe(ops.map(lambda y: '{}{}'.format(x.value, y.value)))
+                return yy.pipe(ops.map(lambda y: "{}{}".format(x.value, y.value)))
 
             return xs.pipe(
                 ops.group_join(
                     ys,
                     lambda x: new_timer(xsd, x.interval, scheduler),
                     lambda y: new_timer(ysd, y.interval, scheduler),
-                    ),
+                ),
                 ops.flat_map(mapper),
-                )
+            )
 
         res = scheduler.start(create=create)
 
@@ -196,13 +194,12 @@ class TestGroup_join(unittest.TestCase):
             on_next(722, "8rat"),
             on_next(732, "7wig"),
             on_next(732, "8wig"),
-            on_completed(910)]
+            on_completed(910),
+        ]
 
-        assert xs.subscriptions == [
-            subscribe(200, 721)]
+        assert xs.subscriptions == [subscribe(200, 721)]
 
-        assert ys.subscriptions == [
-            subscribe(200, 910)]
+        assert ys.subscriptions == [subscribe(200, 910)]
 
     def test_group_join_op_normal_iii(self):
         scheduler = TestScheduler()
@@ -217,7 +214,8 @@ class TestGroup_join(unittest.TestCase):
             on_next(710, TimeInterval(7, 280)),
             on_next(720, TimeInterval(8, 100)),
             on_next(830, TimeInterval(9, 10)),
-            on_completed(900))
+            on_completed(900),
+        )
         ys = scheduler.create_hot_observable(
             on_next(215, TimeInterval("hat", 20)),
             on_next(217, TimeInterval("bat", 1)),
@@ -229,21 +227,26 @@ class TestGroup_join(unittest.TestCase):
             on_next(712, TimeInterval("man", 10)),
             on_next(722, TimeInterval("rat", 200)),
             on_next(732, TimeInterval("wig", 5)),
-            on_completed(800))
+            on_completed(800),
+        )
 
         def create():
             def mapper(x_yy):
                 x, yy = x_yy
-                return yy.pipe(ops.map(lambda y: '{}{}'.format(x.value, y.value)))
+                return yy.pipe(ops.map(lambda y: "{}{}".format(x.value, y.value)))
 
             return xs.pipe(
                 ops.group_join(
                     ys,
-                    lambda x: rx.timer(x.interval).pipe(ops.filter(lambda _: False)),
-                    lambda y: rx.timer(y.interval).pipe(ops.filter(lambda _: False)),
+                    lambda x: reactivex.timer(x.interval).pipe(
+                        ops.filter(lambda _: False)
                     ),
+                    lambda y: reactivex.timer(y.interval).pipe(
+                        ops.filter(lambda _: False)
+                    ),
+                ),
                 ops.flat_map(mapper),
-                )
+            )
 
         results = scheduler.start(create=create)
 
@@ -269,7 +272,8 @@ class TestGroup_join(unittest.TestCase):
             on_next(732, "7wig"),
             on_next(732, "8wig"),
             on_next(830, "9rat"),
-            on_completed(990)]
+            on_completed(990),
+        ]
 
     def test_group_join_op_normal_iv(self):
         scheduler = TestScheduler()
@@ -283,7 +287,8 @@ class TestGroup_join(unittest.TestCase):
             on_next(700, TimeInterval(6, TimeSpan.from_ticks(25))),
             on_next(710, TimeInterval(7, TimeSpan.from_ticks(200))),
             on_next(720, TimeInterval(8, TimeSpan.from_ticks(100))),
-            on_completed(990))
+            on_completed(990),
+        )
         ys = scheduler.create_hot_observable(
             on_next(215, TimeInterval("hat", TimeSpan.from_ticks(20))),
             on_next(217, TimeInterval("bat", TimeSpan.from_ticks(1))),
@@ -295,21 +300,22 @@ class TestGroup_join(unittest.TestCase):
             on_next(712, TimeInterval("man", TimeSpan.from_ticks(10))),
             on_next(722, TimeInterval("rat", TimeSpan.from_ticks(200))),
             on_next(732, TimeInterval("wig", TimeSpan.from_ticks(5))),
-            on_completed(980))
+            on_completed(980),
+        )
 
         def create():
             def mapper(x_yy):
                 x, yy = x_yy
-                return yy.pipe(ops.map(lambda y: '{}{}'.format(x.value, y.value)))
+                return yy.pipe(ops.map(lambda y: "{}{}".format(x.value, y.value)))
 
             return xs.pipe(
                 ops.group_join(
                     ys,
-                    lambda x: rx.timer(x.interval),
-                    lambda y: rx.timer(y.interval),
-                    ),
+                    lambda x: reactivex.timer(x.interval),
+                    lambda y: reactivex.timer(y.interval),
+                ),
                 ops.flat_map(mapper),
-                )
+            )
 
         results = scheduler.start(create=create)
 
@@ -334,7 +340,8 @@ class TestGroup_join(unittest.TestCase):
             on_next(722, "8rat"),
             on_next(732, "7wig"),
             on_next(732, "8wig"),
-            on_completed(990)]
+            on_completed(990),
+        ]
 
     def test_group_join_op_normal_v(self):
         scheduler = TestScheduler()
@@ -348,7 +355,8 @@ class TestGroup_join(unittest.TestCase):
             on_next(700, TimeInterval(6, TimeSpan.from_ticks(25))),
             on_next(710, TimeInterval(7, TimeSpan.from_ticks(200))),
             on_next(720, TimeInterval(8, TimeSpan.from_ticks(100))),
-            on_completed(990))
+            on_completed(990),
+        )
         ys = scheduler.create_hot_observable(
             on_next(215, TimeInterval("hat", TimeSpan.from_ticks(20))),
             on_next(217, TimeInterval("bat", TimeSpan.from_ticks(1))),
@@ -360,21 +368,22 @@ class TestGroup_join(unittest.TestCase):
             on_next(712, TimeInterval("man", TimeSpan.from_ticks(10))),
             on_next(722, TimeInterval("rat", TimeSpan.from_ticks(200))),
             on_next(732, TimeInterval("wig", TimeSpan.from_ticks(5))),
-            on_completed(900))
+            on_completed(900),
+        )
 
         def create():
             def mapper(x_yy):
                 x, yy = x_yy
-                return yy.pipe(ops.map(lambda y: '{}{}'.format(x.value, y.value)))
+                return yy.pipe(ops.map(lambda y: "{}{}".format(x.value, y.value)))
 
             return xs.pipe(
                 ops.group_join(
                     ys,
-                    lambda x: rx.timer(x.interval),
-                    lambda y: rx.timer(y.interval),
-                    ),
+                    lambda x: reactivex.timer(x.interval),
+                    lambda y: reactivex.timer(y.interval),
+                ),
                 ops.flat_map(mapper),
-                )
+            )
 
         results = scheduler.start(create=create)
 
@@ -399,7 +408,8 @@ class TestGroup_join(unittest.TestCase):
             on_next(722, "8rat"),
             on_next(732, "7wig"),
             on_next(732, "8wig"),
-            on_completed(990)]
+            on_completed(990),
+        ]
 
     def test_group_join_op_normal_vi(self):
         scheduler = TestScheduler()
@@ -414,7 +424,8 @@ class TestGroup_join(unittest.TestCase):
             on_next(710, TimeInterval(7, TimeSpan.from_ticks(30))),
             on_next(720, TimeInterval(8, TimeSpan.from_ticks(200))),
             on_next(830, TimeInterval(9, TimeSpan.from_ticks(10))),
-            on_completed(850))
+            on_completed(850),
+        )
         ys = scheduler.create_hot_observable(
             on_next(215, TimeInterval("hat", TimeSpan.from_ticks(20))),
             on_next(217, TimeInterval("bat", TimeSpan.from_ticks(1))),
@@ -426,21 +437,22 @@ class TestGroup_join(unittest.TestCase):
             on_next(712, TimeInterval("man", TimeSpan.from_ticks(10))),
             on_next(722, TimeInterval("rat", TimeSpan.from_ticks(20))),
             on_next(732, TimeInterval("wig", TimeSpan.from_ticks(5))),
-            on_completed(900))
+            on_completed(900),
+        )
 
         def create():
             def mapper(x_yy):
                 x, yy = x_yy
-                return yy.pipe(ops.map(lambda y: '{}{}'.format(x.value, y.value)))
+                return yy.pipe(ops.map(lambda y: "{}{}".format(x.value, y.value)))
 
             return xs.pipe(
                 ops.group_join(
                     ys,
-                    lambda x: rx.timer(x.interval),
-                    lambda y: rx.timer(y.interval),
-                    ),
+                    lambda x: reactivex.timer(x.interval),
+                    lambda y: reactivex.timer(y.interval),
+                ),
                 ops.flat_map(mapper),
-                )
+            )
 
         results = scheduler.start(create=create)
         assert results.messages == [
@@ -464,7 +476,8 @@ class TestGroup_join(unittest.TestCase):
             on_next(722, "8rat"),
             on_next(732, "7wig"),
             on_next(732, "8wig"),
-            on_completed(920)]
+            on_completed(920),
+        ]
 
     def test_group_join_op_normal_vii(self):
         scheduler = TestScheduler()
@@ -480,45 +493,53 @@ class TestGroup_join(unittest.TestCase):
             on_next(712, TimeInterval("man", TimeSpan.from_ticks(10))),
             on_next(722, TimeInterval("rat", TimeSpan.from_ticks(20))),
             on_next(732, TimeInterval("wig", TimeSpan.from_ticks(5))),
-            on_completed(900))
+            on_completed(900),
+        )
 
         def create():
             def mapper(x_yy):
                 x, yy = x_yy
-                return yy.pipe(ops.map(lambda y: '{}{}'.format(x.value, y.value)))
+                return yy.pipe(ops.map(lambda y: "{}{}".format(x.value, y.value)))
 
             return xs.pipe(
                 ops.group_join(
                     ys,
-                    lambda x: rx.timer(x.interval).pipe(ops.filter(lambda _: False)),
-                    lambda y: rx.timer(y.interval).pipe(ops.filter(lambda _: False)),
+                    lambda x: reactivex.timer(x.interval).pipe(
+                        ops.filter(lambda _: False)
                     ),
+                    lambda y: reactivex.timer(y.interval).pipe(
+                        ops.filter(lambda _: False)
+                    ),
+                ),
                 ops.flat_map(mapper),
-                )
+            )
 
         results = scheduler.start(create=create)
         assert results.messages == [on_completed(210)]
 
     def test_group_join_op_normal_viii(self):
         scheduler = TestScheduler()
-        xs = scheduler.create_hot_observable(on_next(210, TimeInterval(0, TimeSpan.from_ticks(200))))
+        xs = scheduler.create_hot_observable(
+            on_next(210, TimeInterval(0, TimeSpan.from_ticks(200)))
+        )
         ys = scheduler.create_hot_observable(
             on_next(220, TimeInterval("hat", TimeSpan.from_ticks(100))),
-            on_completed(230))
+            on_completed(230),
+        )
 
         def create():
             def mapper(x_yy):
                 x, yy = x_yy
-                return yy.pipe(ops.map(lambda y: '{}{}'.format(x.value, y.value)))
+                return yy.pipe(ops.map(lambda y: "{}{}".format(x.value, y.value)))
 
             return xs.pipe(
                 ops.group_join(
                     ys,
-                    lambda x: rx.timer(x.interval),
-                    lambda y: rx.timer(y.interval),
-                    ),
+                    lambda x: reactivex.timer(x.interval),
+                    lambda y: reactivex.timer(y.interval),
+                ),
                 ops.flat_map(mapper),
-                )
+            )
 
         results = scheduler.start(create=create)
         assert results.messages == [on_next(220, "0hat")]
@@ -536,7 +557,8 @@ class TestGroup_join(unittest.TestCase):
             on_next(710, TimeInterval(7, TimeSpan.from_ticks(300))),
             on_next(720, TimeInterval(8, TimeSpan.from_ticks(100))),
             on_next(830, TimeInterval(9, TimeSpan.from_ticks(10))),
-            on_completed(900))
+            on_completed(900),
+        )
         ys = scheduler.create_hot_observable(
             on_next(215, TimeInterval("hat", TimeSpan.from_ticks(20))),
             on_next(217, TimeInterval("bat", TimeSpan.from_ticks(1))),
@@ -548,21 +570,22 @@ class TestGroup_join(unittest.TestCase):
             on_next(712, TimeInterval("man", TimeSpan.from_ticks(10))),
             on_next(722, TimeInterval("rat", TimeSpan.from_ticks(200))),
             on_next(732, TimeInterval("wig", TimeSpan.from_ticks(5))),
-            on_completed(800))
+            on_completed(800),
+        )
 
         def create():
             def mapper(x_yy):
                 x, yy = x_yy
-                return yy.pipe(ops.map(lambda y: '{}{}'.format(x.value, y.value)))
+                return yy.pipe(ops.map(lambda y: "{}{}".format(x.value, y.value)))
 
             return xs.pipe(
                 ops.group_join(
                     ys,
-                    lambda x: rx.timer(x.interval),
-                    lambda y: rx.timer(y.interval),
-                    ),
+                    lambda x: reactivex.timer(x.interval),
+                    lambda y: reactivex.timer(y.interval),
+                ),
                 ops.flat_map(mapper),
-                )
+            )
 
         results = scheduler.start(create=create, disposed=713)
         assert results.messages == [
@@ -578,17 +601,19 @@ class TestGroup_join(unittest.TestCase):
             on_next(702, "6tin"),
             on_next(710, "7tin"),
             on_next(712, "6man"),
-            on_next(712, "7man")]
+            on_next(712, "7man"),
+        ]
 
     def test_group_join_op_error_i(self):
-        ex = 'ex'
+        ex = "ex"
         scheduler = TestScheduler()
         xs = scheduler.create_hot_observable(
             on_next(210, TimeInterval(0, TimeSpan.from_ticks(10))),
             on_next(219, TimeInterval(1, TimeSpan.from_ticks(5))),
             on_next(240, TimeInterval(2, TimeSpan.from_ticks(10))),
             on_next(300, TimeInterval(3, TimeSpan.from_ticks(100))),
-            on_error(310, ex))
+            on_error(310, ex),
+        )
         ys = scheduler.create_hot_observable(
             on_next(215, TimeInterval("hat", TimeSpan.from_ticks(20))),
             on_next(217, TimeInterval("bat", TimeSpan.from_ticks(1))),
@@ -600,21 +625,22 @@ class TestGroup_join(unittest.TestCase):
             on_next(712, TimeInterval("man", TimeSpan.from_ticks(10))),
             on_next(722, TimeInterval("rat", TimeSpan.from_ticks(200))),
             on_next(732, TimeInterval("wig", TimeSpan.from_ticks(5))),
-            on_completed(800))
+            on_completed(800),
+        )
 
         def create():
             def mapper(x_yy):
                 x, yy = x_yy
-                return yy.pipe(ops.map(lambda y: '{}{}'.format(x.value, y.value)))
+                return yy.pipe(ops.map(lambda y: "{}{}".format(x.value, y.value)))
 
             return xs.pipe(
                 ops.group_join(
                     ys,
-                    lambda x: rx.timer(x.interval),
-                    lambda y: rx.timer(y.interval),
-                    ),
+                    lambda x: reactivex.timer(x.interval),
+                    lambda y: reactivex.timer(y.interval),
+                ),
                 ops.flat_map(mapper),
-                )
+            )
 
         results = scheduler.start(create=create)
         assert results.messages == [
@@ -624,10 +650,11 @@ class TestGroup_join(unittest.TestCase):
             on_next(300, "3wag"),
             on_next(300, "3pig"),
             on_next(305, "3cup"),
-            on_error(310, ex)]
+            on_error(310, ex),
+        ]
 
     def test_group_join_op_error_ii(self):
-        ex = 'ex'
+        ex = "ex"
         scheduler = TestScheduler()
         xs = scheduler.create_hot_observable(
             on_next(210, TimeInterval(0, TimeSpan.from_ticks(10))),
@@ -640,7 +667,8 @@ class TestGroup_join(unittest.TestCase):
             on_next(710, TimeInterval(7, TimeSpan.from_ticks(300))),
             on_next(720, TimeInterval(8, TimeSpan.from_ticks(100))),
             on_next(830, TimeInterval(9, TimeSpan.from_ticks(10))),
-            on_completed(900))
+            on_completed(900),
+        )
         ys = scheduler.create_hot_observable(
             on_next(215, TimeInterval("hat", TimeSpan.from_ticks(20))),
             on_next(217, TimeInterval("bat", TimeSpan.from_ticks(1))),
@@ -650,21 +678,22 @@ class TestGroup_join(unittest.TestCase):
             on_next(600, TimeInterval("yak", TimeSpan.from_ticks(90))),
             on_next(702, TimeInterval("tin", TimeSpan.from_ticks(20))),
             on_next(712, TimeInterval("man", TimeSpan.from_ticks(10))),
-            on_error(722, ex))
+            on_error(722, ex),
+        )
 
         def create():
             def mapper(x_yy):
                 x, yy = x_yy
-                return yy.pipe(ops.map(lambda y: '{}{}'.format(x.value, y.value)))
+                return yy.pipe(ops.map(lambda y: "{}{}".format(x.value, y.value)))
 
             return xs.pipe(
                 ops.group_join(
                     ys,
-                    lambda x: rx.timer(x.interval),
-                    lambda y: rx.timer(y.interval),
-                    ),
+                    lambda x: reactivex.timer(x.interval),
+                    lambda y: reactivex.timer(y.interval),
+                ),
                 ops.flat_map(mapper),
-                )
+            )
 
         results = scheduler.start(create=create)
         assert results.messages == [
@@ -683,10 +712,11 @@ class TestGroup_join(unittest.TestCase):
             on_next(712, "7man"),
             on_next(720, "8tin"),
             on_next(720, "8man"),
-            on_error(722, ex)]
+            on_error(722, ex),
+        ]
 
     def test_group_join_op_error_iii(self):
-        ex = 'ex'
+        ex = "ex"
         scheduler = TestScheduler()
         xs = scheduler.create_hot_observable(
             on_next(210, TimeInterval(0, TimeSpan.from_ticks(10))),
@@ -699,7 +729,8 @@ class TestGroup_join(unittest.TestCase):
             on_next(710, TimeInterval(7, TimeSpan.from_ticks(300))),
             on_next(720, TimeInterval(8, TimeSpan.from_ticks(100))),
             on_next(830, TimeInterval(9, TimeSpan.from_ticks(10))),
-            on_completed(900))
+            on_completed(900),
+        )
         ys = scheduler.create_hot_observable(
             on_next(215, TimeInterval("hat", TimeSpan.from_ticks(20))),
             on_next(217, TimeInterval("bat", TimeSpan.from_ticks(1))),
@@ -711,22 +742,26 @@ class TestGroup_join(unittest.TestCase):
             on_next(712, TimeInterval("man", TimeSpan.from_ticks(10))),
             on_next(722, TimeInterval("rat", TimeSpan.from_ticks(200))),
             on_next(732, TimeInterval("wig", TimeSpan.from_ticks(5))),
-            on_completed(800))
+            on_completed(800),
+        )
 
         def create():
             def mapper(x_yy):
                 x, yy = x_yy
-                return yy.pipe(ops.map(lambda y: '{}{}'.format(x.value, y.value)))
+                return yy.pipe(ops.map(lambda y: "{}{}".format(x.value, y.value)))
 
             return xs.pipe(
                 ops.group_join(
                     ys,
-                    lambda x: rx.timer(x.interval).pipe(
-                        ops.flat_map(rx.throw(ex) if x.value == 6 else rx.empty())),
-                    lambda y: rx.timer(y.interval),
+                    lambda x: reactivex.timer(x.interval).pipe(
+                        ops.flat_map(
+                            reactivex.throw(ex) if x.value == 6 else reactivex.empty()
+                        )
                     ),
+                    lambda y: reactivex.timer(y.interval),
+                ),
                 ops.flat_map(mapper),
-                )
+            )
 
         results = scheduler.start(create=create)
         assert results.messages == [
@@ -748,10 +783,11 @@ class TestGroup_join(unittest.TestCase):
             on_next(722, "6rat"),
             on_next(722, "7rat"),
             on_next(722, "8rat"),
-            on_error(725, ex)]
+            on_error(725, ex),
+        ]
 
     def test_group_join_op_error_iv(self):
-        ex = 'ex'
+        ex = "ex"
         scheduler = TestScheduler()
         xs = scheduler.create_hot_observable(
             on_next(210, TimeInterval(0, TimeSpan.from_ticks(10))),
@@ -764,7 +800,8 @@ class TestGroup_join(unittest.TestCase):
             on_next(710, TimeInterval(7, TimeSpan.from_ticks(300))),
             on_next(720, TimeInterval(8, TimeSpan.from_ticks(100))),
             on_next(830, TimeInterval(9, TimeSpan.from_ticks(10))),
-            on_completed(900))
+            on_completed(900),
+        )
         ys = scheduler.create_hot_observable(
             on_next(215, TimeInterval("hat", TimeSpan.from_ticks(20))),
             on_next(217, TimeInterval("bat", TimeSpan.from_ticks(1))),
@@ -776,22 +813,28 @@ class TestGroup_join(unittest.TestCase):
             on_next(712, TimeInterval("man", TimeSpan.from_ticks(10))),
             on_next(722, TimeInterval("rat", TimeSpan.from_ticks(200))),
             on_next(732, TimeInterval("wig", TimeSpan.from_ticks(5))),
-            on_completed(800))
+            on_completed(800),
+        )
 
         def create():
             def mapper(x_yy):
                 x, yy = x_yy
-                return yy.pipe(ops.map(lambda y: '{}{}'.format(x.value, y.value)))
+                return yy.pipe(ops.map(lambda y: "{}{}".format(x.value, y.value)))
 
             return xs.pipe(
                 ops.group_join(
                     ys,
-                    lambda x: rx.timer(x.interval),
-                    lambda y: rx.timer(y.interval).pipe(
-                        ops.flat_map(rx.throw(ex) if y.value == "tin" else rx.empty())),
+                    lambda x: reactivex.timer(x.interval),
+                    lambda y: reactivex.timer(y.interval).pipe(
+                        ops.flat_map(
+                            reactivex.throw(ex)
+                            if y.value == "tin"
+                            else reactivex.empty()
+                        )
                     ),
+                ),
                 ops.flat_map(mapper),
-                )
+            )
 
         results = scheduler.start(create=create)
 
@@ -811,10 +854,11 @@ class TestGroup_join(unittest.TestCase):
             on_next(712, "7man"),
             on_next(720, "8tin"),
             on_next(720, "8man"),
-            on_error(721, ex)]
+            on_error(721, ex),
+        ]
 
     def test_group_join_op_error_v(self):
-        ex = 'ex'
+        ex = "ex"
         scheduler = TestScheduler()
         xs = scheduler.create_hot_observable(
             on_next(210, TimeInterval(0, TimeSpan.from_ticks(10))),
@@ -827,58 +871,7 @@ class TestGroup_join(unittest.TestCase):
             on_next(710, TimeInterval(7, TimeSpan.from_ticks(300))),
             on_next(720, TimeInterval(8, TimeSpan.from_ticks(100))),
             on_next(830, TimeInterval(9, TimeSpan.from_ticks(10))),
-            on_completed(900))
-        ys = scheduler.create_hot_observable(
-            on_next(215, TimeInterval("hat", TimeSpan.from_ticks(20))),
-            on_next(217, TimeInterval("bat", TimeSpan.from_ticks(1))),
-            on_next(290, TimeInterval("wag", TimeSpan.from_ticks(200))),
-            on_next(300, TimeInterval("pig", TimeSpan.from_ticks(10))),
-            on_next(305, TimeInterval("cup", TimeSpan.from_ticks(50))),
-            on_next(600, TimeInterval("yak", TimeSpan.from_ticks(90))),
-            on_next(702, TimeInterval("tin", TimeSpan.from_ticks(20))),
-            on_next(712, TimeInterval("man", TimeSpan.from_ticks(10))),
-            on_next(722, TimeInterval("rat", TimeSpan.from_ticks(200))),
-            on_next(732, TimeInterval("wig", TimeSpan.from_ticks(5))),
-            on_completed(800))
-
-        def create():
-            def left_duration_mapper(x):
-                if x.value >= 0:
-                    raise Exception(ex)
-                else:
-                    return rx.empty()
-
-            def mapper(x_yy):
-                x, yy = x_yy
-                return yy.pipe(ops.map(lambda y: '{}{}'.format(x.value, y.value)))
-
-            return xs.pipe(
-                ops.group_join(
-                    ys,
-                    left_duration_mapper,
-                    lambda y: rx.timer(y.interval),
-                    ),
-                ops.flat_map(mapper),
-                )
-
-        results = scheduler.start(create=create)
-        assert results.messages == [on_error(210, ex)]
-
-    def test_group_join_op_error_vi(self):
-        ex = 'ex'
-        scheduler = TestScheduler()
-        xs = scheduler.create_hot_observable(
-            on_next(210, TimeInterval(0, TimeSpan.from_ticks(10))),
-            on_next(219, TimeInterval(1, TimeSpan.from_ticks(5))),
-            on_next(240, TimeInterval(2, TimeSpan.from_ticks(10))),
-            on_next(300, TimeInterval(3, TimeSpan.from_ticks(100))),
-            on_next(310, TimeInterval(4, TimeSpan.from_ticks(80))),
-            on_next(500, TimeInterval(5, TimeSpan.from_ticks(90))),
-            on_next(700, TimeInterval(6, TimeSpan.from_ticks(25))),
-            on_next(710, TimeInterval(7, TimeSpan.from_ticks(300))),
-            on_next(720, TimeInterval(8, TimeSpan.from_ticks(100))),
-            on_next(830, TimeInterval(9, TimeSpan.from_ticks(10))),
-            on_completed(900)
+            on_completed(900),
         )
         ys = scheduler.create_hot_observable(
             on_next(215, TimeInterval("hat", TimeSpan.from_ticks(20))),
@@ -891,7 +884,60 @@ class TestGroup_join(unittest.TestCase):
             on_next(712, TimeInterval("man", TimeSpan.from_ticks(10))),
             on_next(722, TimeInterval("rat", TimeSpan.from_ticks(200))),
             on_next(732, TimeInterval("wig", TimeSpan.from_ticks(5))),
-            on_completed(800)
+            on_completed(800),
+        )
+
+        def create():
+            def left_duration_mapper(x):
+                if x.value >= 0:
+                    raise Exception(ex)
+                else:
+                    return reactivex.empty()
+
+            def mapper(x_yy):
+                x, yy = x_yy
+                return yy.pipe(ops.map(lambda y: "{}{}".format(x.value, y.value)))
+
+            return xs.pipe(
+                ops.group_join(
+                    ys,
+                    left_duration_mapper,
+                    lambda y: reactivex.timer(y.interval),
+                ),
+                ops.flat_map(mapper),
+            )
+
+        results = scheduler.start(create=create)
+        assert results.messages == [on_error(210, ex)]
+
+    def test_group_join_op_error_vi(self):
+        ex = "ex"
+        scheduler = TestScheduler()
+        xs = scheduler.create_hot_observable(
+            on_next(210, TimeInterval(0, TimeSpan.from_ticks(10))),
+            on_next(219, TimeInterval(1, TimeSpan.from_ticks(5))),
+            on_next(240, TimeInterval(2, TimeSpan.from_ticks(10))),
+            on_next(300, TimeInterval(3, TimeSpan.from_ticks(100))),
+            on_next(310, TimeInterval(4, TimeSpan.from_ticks(80))),
+            on_next(500, TimeInterval(5, TimeSpan.from_ticks(90))),
+            on_next(700, TimeInterval(6, TimeSpan.from_ticks(25))),
+            on_next(710, TimeInterval(7, TimeSpan.from_ticks(300))),
+            on_next(720, TimeInterval(8, TimeSpan.from_ticks(100))),
+            on_next(830, TimeInterval(9, TimeSpan.from_ticks(10))),
+            on_completed(900),
+        )
+        ys = scheduler.create_hot_observable(
+            on_next(215, TimeInterval("hat", TimeSpan.from_ticks(20))),
+            on_next(217, TimeInterval("bat", TimeSpan.from_ticks(1))),
+            on_next(290, TimeInterval("wag", TimeSpan.from_ticks(200))),
+            on_next(300, TimeInterval("pig", TimeSpan.from_ticks(10))),
+            on_next(305, TimeInterval("cup", TimeSpan.from_ticks(50))),
+            on_next(600, TimeInterval("yak", TimeSpan.from_ticks(90))),
+            on_next(702, TimeInterval("tin", TimeSpan.from_ticks(20))),
+            on_next(712, TimeInterval("man", TimeSpan.from_ticks(10))),
+            on_next(722, TimeInterval("rat", TimeSpan.from_ticks(200))),
+            on_next(732, TimeInterval("wig", TimeSpan.from_ticks(5))),
+            on_completed(800),
         )
 
         def create():
@@ -899,24 +945,25 @@ class TestGroup_join(unittest.TestCase):
                 if len(y.value) >= 0:
                     raise Exception(ex)
                 else:
-                    return rx.empty()
+                    return reactivex.empty()
 
             def mapper(x_yy):
                 x, yy = x_yy
-                return yy.pipe(ops.map(lambda y: '{}{}'.format(x.value, y.value)))
+                return yy.pipe(ops.map(lambda y: "{}{}".format(x.value, y.value)))
 
             return xs.pipe(
                 ops.group_join(
                     ys,
-                    lambda x: rx.timer(x.interval),
+                    lambda x: reactivex.timer(x.interval),
                     right_duration_mapper,
-                    ),
+                ),
                 ops.flat_map(mapper),
-                )
+            )
 
         results = scheduler.start(create=create)
 
         assert results.messages == [on_error(215, ex)]
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     unittest.main()
