@@ -1,9 +1,9 @@
 import unittest
 from datetime import timedelta
 
-import rx
-from rx import operators as ops
-from rx.testing import TestScheduler, ReactiveTest
+import reactivex
+from reactivex import operators as ops
+from reactivex.testing import ReactiveTest, TestScheduler
 
 on_next = ReactiveTest.on_next
 on_completed = ReactiveTest.on_completed
@@ -22,7 +22,7 @@ class TimeSpan(object):
 class TimeInterval(object):
     def __init__(self, value, interval):
         if isinstance(interval, timedelta):
-            interval = int(interval.microseconds/1000)
+            interval = int(interval.microseconds / 1000)
 
         self.value = value
         self.interval = interval
@@ -38,7 +38,6 @@ class TimeInterval(object):
 
 
 class TestJoin(unittest.TestCase):
-
     def test_join_op_normal_i(self):
         scheduler = TestScheduler()
         xs = scheduler.create_hot_observable(
@@ -52,7 +51,8 @@ class TestJoin(unittest.TestCase):
             on_next(710, TimeInterval(7, 300)),
             on_next(720, TimeInterval(8, 100)),
             on_next(830, TimeInterval(9, 10)),
-            on_completed(900))
+            on_completed(900),
+        )
 
         ys = scheduler.create_hot_observable(
             on_next(215, TimeInterval("hat", 20)),
@@ -65,7 +65,8 @@ class TestJoin(unittest.TestCase):
             on_next(712, TimeInterval("man", 10)),
             on_next(722, TimeInterval("rat", 200)),
             on_next(732, TimeInterval("wig", 5)),
-            on_completed(800))
+            on_completed(800),
+        )
 
         def create():
             def mapper(xy):
@@ -75,11 +76,11 @@ class TestJoin(unittest.TestCase):
             return xs.pipe(
                 ops.join(
                     ys,
-                    lambda x: rx.timer(x.interval),
-                    lambda y: rx.timer(y.interval),
-                    ),
+                    lambda x: reactivex.timer(x.interval),
+                    lambda y: reactivex.timer(y.interval),
+                ),
                 ops.map(mapper),
-                )
+            )
 
         results = scheduler.start(create=create)
         assert results.messages == [
@@ -104,7 +105,8 @@ class TestJoin(unittest.TestCase):
             on_next(732, "7wig"),
             on_next(732, "8wig"),
             on_next(830, "9rat"),
-            on_completed(900)]
+            on_completed(900),
+        ]
 
     def test_join_op_normal_ii(self):
         scheduler = TestScheduler()
@@ -118,7 +120,8 @@ class TestJoin(unittest.TestCase):
             on_next(700, TimeInterval(6, 25)),
             on_next(710, TimeInterval(7, 200)),
             on_next(720, TimeInterval(8, 100)),
-            on_completed(721))
+            on_completed(721),
+        )
 
         ys = scheduler.create_hot_observable(
             on_next(215, TimeInterval("hat", 20)),
@@ -131,8 +134,8 @@ class TestJoin(unittest.TestCase):
             on_next(712, TimeInterval("man", 10)),
             on_next(722, TimeInterval("rat", 200)),
             on_next(732, TimeInterval("wig", 5)),
-            on_completed(990))
-
+            on_completed(990),
+        )
 
         def create():
             def mapper(xy):
@@ -142,11 +145,11 @@ class TestJoin(unittest.TestCase):
             return xs.pipe(
                 ops.join(
                     ys,
-                    lambda x: rx.timer(x.interval),
-                    lambda y: rx.timer(y.interval),
-                    ),
+                    lambda x: reactivex.timer(x.interval),
+                    lambda y: reactivex.timer(y.interval),
+                ),
                 ops.map(mapper),
-                )
+            )
 
         results = scheduler.start(create=create)
         assert results.messages == [
@@ -170,34 +173,37 @@ class TestJoin(unittest.TestCase):
             on_next(722, "8rat"),
             on_next(732, "7wig"),
             on_next(732, "8wig"),
-            on_completed(910)]
+            on_completed(910),
+        ]
 
     def test_join_op_normal_iii(self):
         scheduler = TestScheduler()
         xs = scheduler.create_hot_observable(
-             on_next(210, TimeInterval(0, 10)),
-             on_next(219, TimeInterval(1, 5)),
-             on_next(240, TimeInterval(2, 10)),
-             on_next(300, TimeInterval(3, 100)),
-             on_next(310, TimeInterval(4, 80)),
-             on_next(500, TimeInterval(5, 90)),
-             on_next(700, TimeInterval(6, 25)),
-             on_next(710, TimeInterval(7, 300)),
-             on_next(720, TimeInterval(8, 100)),
-             on_next(830, TimeInterval(9, 10)),
-             on_completed(900))
+            on_next(210, TimeInterval(0, 10)),
+            on_next(219, TimeInterval(1, 5)),
+            on_next(240, TimeInterval(2, 10)),
+            on_next(300, TimeInterval(3, 100)),
+            on_next(310, TimeInterval(4, 80)),
+            on_next(500, TimeInterval(5, 90)),
+            on_next(700, TimeInterval(6, 25)),
+            on_next(710, TimeInterval(7, 300)),
+            on_next(720, TimeInterval(8, 100)),
+            on_next(830, TimeInterval(9, 10)),
+            on_completed(900),
+        )
         ys = scheduler.create_hot_observable(
-             on_next(215, TimeInterval("hat", 20)),
-             on_next(217, TimeInterval("bat", 1)),
-             on_next(290, TimeInterval("wag", 200)),
-             on_next(300, TimeInterval("pig", 10)),
-             on_next(305, TimeInterval("cup", 50)),
-             on_next(600, TimeInterval("yak", 90)),
-             on_next(702, TimeInterval("tin", 20)),
-             on_next(712, TimeInterval("man", 10)),
-             on_next(722, TimeInterval("rat", 200)),
-             on_next(732, TimeInterval("wig", 5)),
-             on_completed(800))
+            on_next(215, TimeInterval("hat", 20)),
+            on_next(217, TimeInterval("bat", 1)),
+            on_next(290, TimeInterval("wag", 200)),
+            on_next(300, TimeInterval("pig", 10)),
+            on_next(305, TimeInterval("cup", 50)),
+            on_next(600, TimeInterval("yak", 90)),
+            on_next(702, TimeInterval("tin", 20)),
+            on_next(712, TimeInterval("man", 10)),
+            on_next(722, TimeInterval("rat", 200)),
+            on_next(732, TimeInterval("wig", 5)),
+            on_completed(800),
+        )
 
         def create():
             def mapper(xy):
@@ -207,36 +213,41 @@ class TestJoin(unittest.TestCase):
             return xs.pipe(
                 ops.join(
                     ys,
-                    lambda x: rx.timer(x.interval).pipe(ops.filter(lambda _: False)),
-                    lambda y: rx.timer(y.interval).pipe(ops.filter(lambda _: False)),
+                    lambda x: reactivex.timer(x.interval).pipe(
+                        ops.filter(lambda _: False)
                     ),
+                    lambda y: reactivex.timer(y.interval).pipe(
+                        ops.filter(lambda _: False)
+                    ),
+                ),
                 ops.map(mapper),
-                )
+            )
 
         results = scheduler.start(create=create)
         assert results.messages == [
-             on_next(215, "0hat"),
-             on_next(217, "0bat"),
-             on_next(219, "1hat"),
-             on_next(300, "3wag"),
-             on_next(300, "3pig"),
-             on_next(305, "3cup"),
-             on_next(310, "4wag"),
-             on_next(310, "4pig"),
-             on_next(310, "4cup"),
-             on_next(702, "6tin"),
-             on_next(710, "7tin"),
-             on_next(712, "6man"),
-             on_next(712, "7man"),
-             on_next(720, "8tin"),
-             on_next(720, "8man"),
-             on_next(722, "6rat"),
-             on_next(722, "7rat"),
-             on_next(722, "8rat"),
-             on_next(732, "7wig"),
-             on_next(732, "8wig"),
-             on_next(830, "9rat"),
-             on_completed(900)]
+            on_next(215, "0hat"),
+            on_next(217, "0bat"),
+            on_next(219, "1hat"),
+            on_next(300, "3wag"),
+            on_next(300, "3pig"),
+            on_next(305, "3cup"),
+            on_next(310, "4wag"),
+            on_next(310, "4pig"),
+            on_next(310, "4cup"),
+            on_next(702, "6tin"),
+            on_next(710, "7tin"),
+            on_next(712, "6man"),
+            on_next(712, "7man"),
+            on_next(720, "8tin"),
+            on_next(720, "8man"),
+            on_next(722, "6rat"),
+            on_next(722, "7rat"),
+            on_next(722, "8rat"),
+            on_next(732, "7wig"),
+            on_next(732, "8wig"),
+            on_next(830, "9rat"),
+            on_completed(900),
+        ]
 
     def test_join_op_normal_iv(self):
         scheduler = TestScheduler()
@@ -250,7 +261,8 @@ class TestJoin(unittest.TestCase):
             on_next(700, TimeInterval(6, 25)),
             on_next(710, TimeInterval(7, 200)),
             on_next(720, TimeInterval(8, 100)),
-            on_completed(990))
+            on_completed(990),
+        )
         ys = scheduler.create_hot_observable(
             on_next(215, TimeInterval("hat", 20)),
             on_next(217, TimeInterval("bat", 1)),
@@ -262,7 +274,8 @@ class TestJoin(unittest.TestCase):
             on_next(712, TimeInterval("man", 10)),
             on_next(722, TimeInterval("rat", 200)),
             on_next(732, TimeInterval("wig", 5)),
-            on_completed(980))
+            on_completed(980),
+        )
 
         def create():
             def mapper(xy):
@@ -272,11 +285,11 @@ class TestJoin(unittest.TestCase):
             return xs.pipe(
                 ops.join(
                     ys,
-                    lambda x: rx.timer(x.interval),
-                    lambda y: rx.timer(y.interval),
-                    ),
+                    lambda x: reactivex.timer(x.interval),
+                    lambda y: reactivex.timer(y.interval),
+                ),
                 ops.map(mapper),
-                )
+            )
 
         results = scheduler.start(create=create)
 
@@ -301,7 +314,8 @@ class TestJoin(unittest.TestCase):
             on_next(722, "8rat"),
             on_next(732, "7wig"),
             on_next(732, "8wig"),
-            on_completed(980)]
+            on_completed(980),
+        ]
 
     def test_join_op_normal_v(self):
         scheduler = TestScheduler()
@@ -315,7 +329,8 @@ class TestJoin(unittest.TestCase):
             on_next(700, TimeInterval(6, 25)),
             on_next(710, TimeInterval(7, 200)),
             on_next(720, TimeInterval(8, 100)),
-            on_completed(990))
+            on_completed(990),
+        )
         ys = scheduler.create_hot_observable(
             on_next(215, TimeInterval("hat", 20)),
             on_next(217, TimeInterval("bat", 1)),
@@ -327,7 +342,8 @@ class TestJoin(unittest.TestCase):
             on_next(712, TimeInterval("man", 10)),
             on_next(722, TimeInterval("rat", 200)),
             on_next(732, TimeInterval("wig", 5)),
-            on_completed(900))
+            on_completed(900),
+        )
 
         def create():
             def mapper(xy):
@@ -337,11 +353,11 @@ class TestJoin(unittest.TestCase):
             return xs.pipe(
                 ops.join(
                     ys,
-                    lambda x: rx.timer(x.interval),
-                    lambda y: rx.timer(y.interval),
-                    ),
+                    lambda x: reactivex.timer(x.interval),
+                    lambda y: reactivex.timer(y.interval),
+                ),
                 ops.map(mapper),
-                )
+            )
 
         results = scheduler.start(create=create)
 
@@ -366,7 +382,8 @@ class TestJoin(unittest.TestCase):
             on_next(722, "8rat"),
             on_next(732, "7wig"),
             on_next(732, "8wig"),
-            on_completed(922)]
+            on_completed(922),
+        ]
 
     def test_join_op_normal_vi(self):
         scheduler = TestScheduler()
@@ -381,7 +398,8 @@ class TestJoin(unittest.TestCase):
             on_next(710, TimeInterval(7, 30)),
             on_next(720, TimeInterval(8, 200)),
             on_next(830, TimeInterval(9, 10)),
-            on_completed(850))
+            on_completed(850),
+        )
         ys = scheduler.create_hot_observable(
             on_next(215, TimeInterval("hat", 20)),
             on_next(217, TimeInterval("bat", 1)),
@@ -393,7 +411,8 @@ class TestJoin(unittest.TestCase):
             on_next(712, TimeInterval("man", 10)),
             on_next(722, TimeInterval("rat", 20)),
             on_next(732, TimeInterval("wig", 5)),
-            on_completed(900))
+            on_completed(900),
+        )
 
         def create():
             def mapper(xy):
@@ -403,11 +422,11 @@ class TestJoin(unittest.TestCase):
             return xs.pipe(
                 ops.join(
                     ys,
-                    lambda x: rx.timer(x.interval),
-                    lambda y: rx.timer(y.interval),
-                    ),
+                    lambda x: reactivex.timer(x.interval),
+                    lambda y: reactivex.timer(y.interval),
+                ),
                 ops.map(mapper),
-                )
+            )
 
         results = scheduler.start(create=create)
 
@@ -432,7 +451,8 @@ class TestJoin(unittest.TestCase):
             on_next(722, "8rat"),
             on_next(732, "7wig"),
             on_next(732, "8wig"),
-            on_completed(900)]
+            on_completed(900),
+        ]
 
     def test_join_op_normal_vii(self):
         scheduler = TestScheduler()
@@ -447,7 +467,8 @@ class TestJoin(unittest.TestCase):
             on_next(710, TimeInterval(7, 300)),
             on_next(720, TimeInterval(8, 100)),
             on_next(830, TimeInterval(9, 10)),
-            on_completed(900))
+            on_completed(900),
+        )
         ys = scheduler.create_hot_observable(
             on_next(215, TimeInterval("hat", 20)),
             on_next(217, TimeInterval("bat", 1)),
@@ -459,7 +480,8 @@ class TestJoin(unittest.TestCase):
             on_next(712, TimeInterval("man", 10)),
             on_next(722, TimeInterval("rat", 200)),
             on_next(732, TimeInterval("wig", 5)),
-            on_completed(800))
+            on_completed(800),
+        )
 
         def create():
             def mapper(xy):
@@ -469,11 +491,11 @@ class TestJoin(unittest.TestCase):
             return xs.pipe(
                 ops.join(
                     ys,
-                    lambda x: rx.timer(x.interval),
-                    lambda y: rx.timer(y.interval),
-                    ),
+                    lambda x: reactivex.timer(x.interval),
+                    lambda y: reactivex.timer(y.interval),
+                ),
                 ops.map(mapper),
-                )
+            )
 
         results = scheduler.start(create, disposed=713)
         assert results.messages == [
@@ -489,17 +511,19 @@ class TestJoin(unittest.TestCase):
             on_next(702, "6tin"),
             on_next(710, "7tin"),
             on_next(712, "6man"),
-            on_next(712, "7man")]
+            on_next(712, "7man"),
+        ]
 
     def test_join_op_error_i(self):
-        ex = 'ex'
+        ex = "ex"
         scheduler = TestScheduler()
         xs = scheduler.create_hot_observable(
             on_next(210, TimeInterval(0, 10)),
             on_next(219, TimeInterval(1, 5)),
             on_next(240, TimeInterval(2, 10)),
             on_next(300, TimeInterval(3, 100)),
-            on_error(310, ex))
+            on_error(310, ex),
+        )
         ys = scheduler.create_hot_observable(
             on_next(215, TimeInterval("hat", 20)),
             on_next(217, TimeInterval("bat", 1)),
@@ -511,7 +535,8 @@ class TestJoin(unittest.TestCase):
             on_next(712, TimeInterval("man", 10)),
             on_next(722, TimeInterval("rat", 200)),
             on_next(732, TimeInterval("wig", 5)),
-            on_completed(800))
+            on_completed(800),
+        )
 
         def create():
             def mapper(xy):
@@ -521,11 +546,11 @@ class TestJoin(unittest.TestCase):
             return xs.pipe(
                 ops.join(
                     ys,
-                    lambda x: rx.timer(x.interval),
-                    lambda y: rx.timer(y.interval),
-                    ),
+                    lambda x: reactivex.timer(x.interval),
+                    lambda y: reactivex.timer(y.interval),
+                ),
                 ops.map(mapper),
-                    )
+            )
 
         results = scheduler.start(create=create, disposed=713)
         assert results.messages == [
@@ -535,10 +560,11 @@ class TestJoin(unittest.TestCase):
             on_next(300, "3wag"),
             on_next(300, "3pig"),
             on_next(305, "3cup"),
-            on_error(310, ex)]
+            on_error(310, ex),
+        ]
 
     def test_join_op_error_ii(self):
-        ex = 'ex'
+        ex = "ex"
         scheduler = TestScheduler()
         xs = scheduler.create_hot_observable(
             on_next(210, TimeInterval(0, 10)),
@@ -551,7 +577,8 @@ class TestJoin(unittest.TestCase):
             on_next(710, TimeInterval(7, 300)),
             on_next(720, TimeInterval(8, 100)),
             on_next(830, TimeInterval(9, 10)),
-            on_completed(900))
+            on_completed(900),
+        )
         ys = scheduler.create_hot_observable(
             on_next(215, TimeInterval("hat", 20)),
             on_next(217, TimeInterval("bat", 1)),
@@ -561,7 +588,8 @@ class TestJoin(unittest.TestCase):
             on_next(600, TimeInterval("yak", 90)),
             on_next(702, TimeInterval("tin", 20)),
             on_next(712, TimeInterval("man", 10)),
-            on_error(722, ex))
+            on_error(722, ex),
+        )
 
         def create():
             def mapper(xy):
@@ -571,11 +599,11 @@ class TestJoin(unittest.TestCase):
             return xs.pipe(
                 ops.join(
                     ys,
-                    lambda x: rx.timer(x.interval),
-                    lambda y: rx.timer(y.interval),
-                    ),
+                    lambda x: reactivex.timer(x.interval),
+                    lambda y: reactivex.timer(y.interval),
+                ),
                 ops.map(mapper),
-                )
+            )
 
         results = scheduler.start(create=create)
 
@@ -595,10 +623,11 @@ class TestJoin(unittest.TestCase):
             on_next(712, "7man"),
             on_next(720, "8tin"),
             on_next(720, "8man"),
-            on_error(722, ex)]
+            on_error(722, ex),
+        ]
 
     def test_join_op_error_iii(self):
-        ex = 'ex'
+        ex = "ex"
         scheduler = TestScheduler()
         xs = scheduler.create_hot_observable(
             on_next(210, TimeInterval(0, 10)),
@@ -611,7 +640,8 @@ class TestJoin(unittest.TestCase):
             on_next(710, TimeInterval(7, 300)),
             on_next(720, TimeInterval(8, 100)),
             on_next(830, TimeInterval(9, 10)),
-            on_completed(900))
+            on_completed(900),
+        )
         ys = scheduler.create_hot_observable(
             on_next(215, TimeInterval("hat", 20)),
             on_next(217, TimeInterval("bat", 1)),
@@ -623,7 +653,8 @@ class TestJoin(unittest.TestCase):
             on_next(712, TimeInterval("man", 10)),
             on_next(722, TimeInterval("rat", 200)),
             on_next(732, TimeInterval("wig", 5)),
-            on_completed(800))
+            on_completed(800),
+        )
 
         def create():
             def mapper(xy):
@@ -633,11 +664,15 @@ class TestJoin(unittest.TestCase):
             return xs.pipe(
                 ops.join(
                     ys,
-                    lambda x: rx.timer(x.interval).pipe(ops.flat_map(rx.throw(ex) if x.value == 6 else rx.empty())),
-                    lambda y: rx.timer(y.interval),
+                    lambda x: reactivex.timer(x.interval).pipe(
+                        ops.flat_map(
+                            reactivex.throw(ex) if x.value == 6 else reactivex.empty()
+                        )
                     ),
+                    lambda y: reactivex.timer(y.interval),
+                ),
                 ops.map(mapper),
-                )
+            )
 
         results = scheduler.start(create=create)
 
@@ -660,10 +695,11 @@ class TestJoin(unittest.TestCase):
             on_next(722, "6rat"),
             on_next(722, "7rat"),
             on_next(722, "8rat"),
-            on_error(725, ex)]
+            on_error(725, ex),
+        ]
 
     def test_join_op_error_iv(self):
-        ex = 'ex'
+        ex = "ex"
         scheduler = TestScheduler()
         xs = scheduler.create_hot_observable(
             on_next(210, TimeInterval(0, 10)),
@@ -676,7 +712,8 @@ class TestJoin(unittest.TestCase):
             on_next(710, TimeInterval(7, 300)),
             on_next(720, TimeInterval(8, 100)),
             on_next(830, TimeInterval(9, 10)),
-            on_completed(900))
+            on_completed(900),
+        )
         ys = scheduler.create_hot_observable(
             on_next(215, TimeInterval("hat", 20)),
             on_next(217, TimeInterval("bat", 1)),
@@ -688,7 +725,8 @@ class TestJoin(unittest.TestCase):
             on_next(712, TimeInterval("man", 10)),
             on_next(722, TimeInterval("rat", 200)),
             on_next(732, TimeInterval("wig", 5)),
-            on_completed(800))
+            on_completed(800),
+        )
 
         def create():
             def mapper(xy):
@@ -698,11 +736,17 @@ class TestJoin(unittest.TestCase):
             return xs.pipe(
                 ops.join(
                     ys,
-                    lambda x: rx.timer(x.interval),
-                    lambda y: rx.timer(y.interval).pipe(ops.flat_map(rx.throw(ex) if y.value == "tin" else rx.empty())),
+                    lambda x: reactivex.timer(x.interval),
+                    lambda y: reactivex.timer(y.interval).pipe(
+                        ops.flat_map(
+                            reactivex.throw(ex)
+                            if y.value == "tin"
+                            else reactivex.empty()
+                        )
                     ),
+                ),
                 ops.map(mapper),
-                )
+            )
 
         results = scheduler.start(create=create)
 
@@ -722,10 +766,11 @@ class TestJoin(unittest.TestCase):
             on_next(712, "7man"),
             on_next(720, "8tin"),
             on_next(720, "8man"),
-            on_error(721, ex)]
+            on_error(721, ex),
+        ]
 
     def test_join_op_error_v(self):
-        ex = 'ex'
+        ex = "ex"
         scheduler = TestScheduler()
         xs = scheduler.create_hot_observable(
             on_next(210, TimeInterval(0, 10)),
@@ -738,7 +783,8 @@ class TestJoin(unittest.TestCase):
             on_next(710, TimeInterval(7, 300)),
             on_next(720, TimeInterval(8, 100)),
             on_next(830, TimeInterval(9, 10)),
-            on_completed(900))
+            on_completed(900),
+        )
         ys = scheduler.create_hot_observable(
             on_next(215, TimeInterval("hat", 20)),
             on_next(217, TimeInterval("bat", 1)),
@@ -750,14 +796,15 @@ class TestJoin(unittest.TestCase):
             on_next(712, TimeInterval("man", 10)),
             on_next(722, TimeInterval("rat", 200)),
             on_next(732, TimeInterval("wig", 5)),
-            on_completed(800))
+            on_completed(800),
+        )
 
         def create():
             def left_duration_mapper(x):
                 if x.value >= 0:
                     raise Exception(ex)
                 else:
-                    return rx.empty()
+                    return reactivex.empty()
 
             def mapper(xy):
                 x, y = xy
@@ -767,17 +814,17 @@ class TestJoin(unittest.TestCase):
                 ops.join(
                     ys,
                     left_duration_mapper,
-                    lambda y: rx.timer(y.interval),
-                    ),
+                    lambda y: reactivex.timer(y.interval),
+                ),
                 ops.map(mapper),
-                )
+            )
 
         results = scheduler.start(create=create)
 
         assert results.messages == [on_error(210, ex)]
 
     def test_join_op_error_vi(self):
-        ex = 'ex'
+        ex = "ex"
         scheduler = TestScheduler()
         xs = scheduler.create_hot_observable(
             on_next(210, TimeInterval(0, 10)),
@@ -790,7 +837,8 @@ class TestJoin(unittest.TestCase):
             on_next(710, TimeInterval(7, 300)),
             on_next(720, TimeInterval(8, 100)),
             on_next(830, TimeInterval(9, 10)),
-            on_completed(900))
+            on_completed(900),
+        )
         ys = scheduler.create_hot_observable(
             on_next(215, TimeInterval("hat", 20)),
             on_next(217, TimeInterval("bat", 1)),
@@ -802,14 +850,15 @@ class TestJoin(unittest.TestCase):
             on_next(712, TimeInterval("man", 10)),
             on_next(722, TimeInterval("rat", 200)),
             on_next(732, TimeInterval("wig", 5)),
-            on_completed(800))
+            on_completed(800),
+        )
 
         def create():
             def right_duration_mapper(y):
                 if len(y.value) >= 0:
                     raise Exception(ex)
                 else:
-                    return rx.empty()
+                    return reactivex.empty()
 
             def mapper(xy):
                 x, y = xy
@@ -818,11 +867,11 @@ class TestJoin(unittest.TestCase):
             return xs.pipe(
                 ops.join(
                     ys,
-                    lambda x: rx.timer(x.interval),
+                    lambda x: reactivex.timer(x.interval),
                     right_duration_mapper,
-                    ),
+                ),
                 ops.map(mapper),
-                )
+            )
 
         results = scheduler.start(create=create)
 
@@ -832,32 +881,32 @@ class TestJoin(unittest.TestCase):
         scheduler = TestScheduler()
 
         subscribe_schedulers = {
-            'x': 'unknown',
-            'y': 'unknown',
-            'duration_x': 'unknown',
-            'duration_y': 'unknown',
-            }
+            "x": "unknown",
+            "y": "unknown",
+            "duration_x": "unknown",
+            "duration_y": "unknown",
+        }
 
-        def subscribe_x(observer, scheduler='not_set'):
-            subscribe_schedulers['x'] = scheduler
+        def subscribe_x(observer, scheduler="not_set"):
+            subscribe_schedulers["x"] = scheduler
             # need to push one element to trigger duration mapper
-            observer.on_next('foo')
+            observer.on_next("foo")
 
-        def subscribe_y(observer, scheduler='not_set'):
-            subscribe_schedulers['y'] = scheduler
+        def subscribe_y(observer, scheduler="not_set"):
+            subscribe_schedulers["y"] = scheduler
             # need to push one element to trigger duration mapper
-            observer.on_next('bar')
+            observer.on_next("bar")
 
-        def subscribe_duration_x(observer, scheduler='not_set'):
-            subscribe_schedulers['duration_x'] = scheduler
+        def subscribe_duration_x(observer, scheduler="not_set"):
+            subscribe_schedulers["duration_x"] = scheduler
 
-        def subscribe_duration_y(observer, scheduler='not_set'):
-            subscribe_schedulers['duration_y'] = scheduler
+        def subscribe_duration_y(observer, scheduler="not_set"):
+            subscribe_schedulers["duration_y"] = scheduler
 
-        xs = rx.create(subscribe_x)
-        ys = rx.create(subscribe_y)
-        duration_x = rx.create(subscribe_duration_x)
-        duration_y = rx.create(subscribe_duration_y)
+        xs = reactivex.create(subscribe_x)
+        ys = reactivex.create(subscribe_y)
+        duration_x = reactivex.create(subscribe_duration_x)
+        duration_y = reactivex.create(subscribe_duration_y)
 
         def create():
             return xs.pipe(
@@ -865,56 +914,55 @@ class TestJoin(unittest.TestCase):
                     ys,
                     lambda x: duration_x,
                     lambda y: duration_y,
-                    ),
-                )
+                ),
+            )
 
         results = scheduler.start(create=create)
-        assert subscribe_schedulers['x'] is scheduler
-        assert subscribe_schedulers['y'] is scheduler
-        assert subscribe_schedulers['duration_x'] is scheduler
-        assert subscribe_schedulers['duration_y'] is scheduler
+        assert subscribe_schedulers["x"] is scheduler
+        assert subscribe_schedulers["y"] is scheduler
+        assert subscribe_schedulers["duration_x"] is scheduler
+        assert subscribe_schedulers["duration_y"] is scheduler
 
     def test_join_op_forward_scheduler_None(self):
 
         subscribe_schedulers = {
-            'x': 'unknown',
-            'y': 'unknown',
-            'duration_x': 'unknown',
-            'duration_y': 'unknown',
-            }
+            "x": "unknown",
+            "y": "unknown",
+            "duration_x": "unknown",
+            "duration_y": "unknown",
+        }
 
-        def subscribe_x(observer, scheduler='not_set'):
-            subscribe_schedulers['x'] = scheduler
+        def subscribe_x(observer, scheduler="not_set"):
+            subscribe_schedulers["x"] = scheduler
             # need to push one element to trigger duration mapper
-            observer.on_next('foo')
+            observer.on_next("foo")
 
-        def subscribe_y(observer, scheduler='not_set'):
-            subscribe_schedulers['y'] = scheduler
+        def subscribe_y(observer, scheduler="not_set"):
+            subscribe_schedulers["y"] = scheduler
             # need to push one element to trigger duration mapper
-            observer.on_next('bar')
+            observer.on_next("bar")
 
-        def subscribe_duration_x(observer, scheduler='not_set'):
-            subscribe_schedulers['duration_x'] = scheduler
+        def subscribe_duration_x(observer, scheduler="not_set"):
+            subscribe_schedulers["duration_x"] = scheduler
 
-        def subscribe_duration_y(observer, scheduler='not_set'):
-            subscribe_schedulers['duration_y'] = scheduler
+        def subscribe_duration_y(observer, scheduler="not_set"):
+            subscribe_schedulers["duration_y"] = scheduler
 
-        xs = rx.create(subscribe_x)
-        ys = rx.create(subscribe_y)
-        duration_x = rx.create(subscribe_duration_x)
-        duration_y = rx.create(subscribe_duration_y)
+        xs = reactivex.create(subscribe_x)
+        ys = reactivex.create(subscribe_y)
+        duration_x = reactivex.create(subscribe_duration_x)
+        duration_y = reactivex.create(subscribe_duration_y)
 
         stream = xs.pipe(
             ops.join(
                 ys,
                 lambda x: duration_x,
                 lambda y: duration_y,
-                ),
-            )
+            ),
+        )
 
         stream.subscribe()
-        assert subscribe_schedulers['x'] is None
-        assert subscribe_schedulers['y'] is None
-        assert subscribe_schedulers['duration_x'] is None
-        assert subscribe_schedulers['duration_y'] is None
-
+        assert subscribe_schedulers["x"] is None
+        assert subscribe_schedulers["y"] is None
+        assert subscribe_schedulers["duration_x"] is None
+        assert subscribe_schedulers["duration_y"] is None
