@@ -1,12 +1,11 @@
-
-import unittest
 import asyncio
+import unittest
 
-import rx
-import rx.operators as ops
-from rx.internal.exceptions import SequenceContainsNoElementsError
-from rx.testing import ReactiveTest
-from rx.subject import Subject
+import reactivex
+import reactivex.operators as ops
+from reactivex.internal.exceptions import SequenceContainsNoElementsError
+from reactivex.subject import Subject
+from reactivex.testing import ReactiveTest
 
 on_next = ReactiveTest.on_next
 on_completed = ReactiveTest.on_completed
@@ -24,7 +23,7 @@ class TestToFuture(unittest.TestCase):
 
         async def go():
             nonlocal result
-            source = rx.return_value(42)
+            source = reactivex.return_value(42)
             result = await source
 
         loop.run_until_complete(go())
@@ -36,7 +35,7 @@ class TestToFuture(unittest.TestCase):
 
         async def go():
             nonlocal result
-            source = rx.from_([40, 41, 42])
+            source = reactivex.from_([40, 41, 42])
             result = await source
 
         loop.run_until_complete(go())
@@ -49,7 +48,7 @@ class TestToFuture(unittest.TestCase):
 
         async def go():
             nonlocal result
-            source = rx.throw(error)
+            source = reactivex.throw(error)
             try:
                 result = await source
             except Exception as ex:
@@ -64,10 +63,12 @@ class TestToFuture(unittest.TestCase):
 
         async def go():
             nonlocal result
-            source = rx.empty()
+            source = reactivex.empty()
             result = await source
 
-        self.assertRaises(SequenceContainsNoElementsError, loop.run_until_complete, go())
+        self.assertRaises(
+            SequenceContainsNoElementsError, loop.run_until_complete, go()
+        )
 
     def test_await_with_delay(self):
         loop = asyncio.get_event_loop()
@@ -75,7 +76,7 @@ class TestToFuture(unittest.TestCase):
 
         async def go():
             nonlocal result
-            source = rx.return_value(42).pipe(ops.delay(0.1))
+            source = reactivex.return_value(42).pipe(ops.delay(0.1))
             result = await source
 
         loop.run_until_complete(go())
@@ -85,7 +86,7 @@ class TestToFuture(unittest.TestCase):
         loop = asyncio.get_event_loop()
 
         async def go():
-            source = rx.return_value(42)
+            source = reactivex.return_value(42)
             fut = next(source.__await__())
             # This used to raise an InvalidStateError before we got
             # support for cancellation.
@@ -101,7 +102,7 @@ class TestToFuture(unittest.TestCase):
         async def using_sub():
             # Since the subject never completes, this await statement
             # will never be complete either. We wait forever.
-            await rx.using(lambda: sub, lambda s: s)
+            await reactivex.using(lambda: sub, lambda s: s)
 
         async def go():
             await asyncio.wait_for(using_sub(), 0.1)
