@@ -1,8 +1,8 @@
 import unittest
 
-import rx
-from rx import operators as ops
-from rx.testing import TestScheduler, ReactiveTest
+import reactivex
+from reactivex import operators as ops
+from reactivex.testing import ReactiveTest, TestScheduler
 
 on_next = ReactiveTest.on_next
 on_completed = ReactiveTest.on_completed
@@ -14,11 +14,10 @@ created = ReactiveTest.created
 
 
 class TestZip(unittest.TestCase):
-
     def test_zip_never_never(self):
         scheduler = TestScheduler()
-        o1 = rx.never()
-        o2 = rx.never()
+        o1 = reactivex.never()
+        o2 = reactivex.never()
 
         def create():
             return o1.pipe(ops.zip(o2))
@@ -29,7 +28,7 @@ class TestZip(unittest.TestCase):
     def test_zip_never_empty(self):
         scheduler = TestScheduler()
         msgs = [on_next(150, 1), on_completed(210)]
-        o1 = rx.never()
+        o1 = reactivex.never()
         o2 = scheduler.create_hot_observable(msgs)
 
         def create():
@@ -46,9 +45,7 @@ class TestZip(unittest.TestCase):
         e2 = scheduler.create_hot_observable(msgs2)
 
         def create():
-            return e1.pipe(
-                ops.zip(e2),
-                ops.map(sum))
+            return e1.pipe(ops.zip(e2), ops.map(sum))
 
         results = scheduler.start(create)
         assert results.messages == [on_completed(210)]
@@ -61,9 +58,7 @@ class TestZip(unittest.TestCase):
         e2 = scheduler.create_hot_observable(msgs2)
 
         def create():
-            return e1.pipe(
-                ops.zip(e2),
-                ops.map(sum))
+            return e1.pipe(ops.zip(e2), ops.map(sum))
 
         results = scheduler.start(create)
         assert results.messages == [on_completed(210)]
@@ -76,9 +71,7 @@ class TestZip(unittest.TestCase):
         e2 = scheduler.create_hot_observable(msgs2)
 
         def create():
-            return e2.pipe(
-                ops.zip(e1),
-                ops.map(sum))
+            return e2.pipe(ops.zip(e1), ops.map(sum))
 
         results = scheduler.start(create)
         assert results.messages == [on_completed(210)]
@@ -87,29 +80,25 @@ class TestZip(unittest.TestCase):
         scheduler = TestScheduler()
         msgs = [on_next(150, 1), on_next(215, 2), on_completed(220)]
         e1 = scheduler.create_hot_observable(msgs)
-        e2 = rx.never()
+        e2 = reactivex.never()
 
         def create():
-            return e2.pipe(
-                ops.zip(e1),
-                ops.map(sum))
+            return e2.pipe(ops.zip(e1), ops.map(sum))
 
         results = scheduler.start(create)
-        assert results.messages == [on_completed(220)]
+        assert results.messages == []
 
     def test_zip_non_empty_never(self):
         scheduler = TestScheduler()
         msgs = [on_next(150, 1), on_next(215, 2), on_completed(220)]
         e1 = scheduler.create_hot_observable(msgs)
-        e2 = rx.never()
+        e2 = reactivex.never()
 
         def create():
-            return e1.pipe(
-                ops.zip(e2),
-                ops.map(sum))
+            return e1.pipe(ops.zip(e2), ops.map(sum))
 
         results = scheduler.start(create)
-        assert results.messages == [on_completed(220)]
+        assert results.messages == []
 
     def test_zip_non_empty_non_empty(self):
         scheduler = TestScheduler()
@@ -119,15 +108,43 @@ class TestZip(unittest.TestCase):
         e2 = scheduler.create_hot_observable(msgs2)
 
         def create():
-            return e1.pipe(
-                ops.zip(e2),
-                ops.map(sum))
+            return e1.pipe(ops.zip(e2), ops.map(sum))
 
         results = scheduler.start(create)
         assert results.messages == [on_next(220, 2 + 3), on_completed(230)]
 
+    def test_zip_non_empty_non_empty_sequential(self):
+        scheduler = TestScheduler()
+        msgs1 = [on_next(210, 1), on_next(215, 2), on_completed(230)]
+        msgs2 = [on_next(240, 1), on_next(245, 3), on_completed(250)]
+        e1 = scheduler.create_cold_observable(msgs1)
+        e2 = scheduler.create_cold_observable(msgs2)
+
+        def create():
+            return e1.pipe(ops.zip(e2), ops.map(sum))
+
+        results = scheduler.start(create)
+        assert results.messages == [
+            on_next(200 + 240, 1 + 1),
+            on_next(200 + 245, 2 + 3),
+            on_completed(200 + 245),
+        ]
+
+    def test_zip_non_empty_partial_sequential(self):
+        scheduler = TestScheduler()
+        msgs1 = [on_next(210, 1), on_next(215, 2), on_completed(230)]
+        msgs2 = [on_next(240, 1), on_completed(250)]
+        e1 = scheduler.create_cold_observable(msgs1)
+        e2 = scheduler.create_cold_observable(msgs2)
+
+        def create():
+            return e1.pipe(ops.zip(e2), ops.map(sum))
+
+        results = scheduler.start(create)
+        assert results.messages == [on_next(200 + 240, 1 + 1), on_completed(200 + 250)]
+
     def test_zip_empty_error(self):
-        ex = 'ex'
+        ex = "ex"
         scheduler = TestScheduler()
         msgs1 = [on_next(150, 1), on_completed(230)]
         msgs2 = [on_next(150, 1), on_error(220, ex)]
@@ -135,15 +152,13 @@ class TestZip(unittest.TestCase):
         e2 = scheduler.create_hot_observable(msgs2)
 
         def create():
-            return e1.pipe(
-                ops.zip(e2),
-                ops.map(sum))
+            return e1.pipe(ops.zip(e2), ops.map(sum))
 
         results = scheduler.start(create)
         assert results.messages == [on_error(220, ex)]
 
     def test_zip_error_empty(self):
-        ex = 'ex'
+        ex = "ex"
         scheduler = TestScheduler()
         msgs1 = [on_next(150, 1), on_completed(230)]
         msgs2 = [on_next(150, 1), on_error(220, ex)]
@@ -151,46 +166,40 @@ class TestZip(unittest.TestCase):
         e2 = scheduler.create_hot_observable(msgs2)
 
         def create():
-            return e2.pipe(
-                ops.zip(e1),
-                ops.map(sum))
+            return e2.pipe(ops.zip(e1), ops.map(sum))
 
         results = scheduler.start(create)
         assert results.messages == [on_error(220, ex)]
 
     def test_zip_never_error(self):
-        ex = 'ex'
+        ex = "ex"
         scheduler = TestScheduler()
         msgs2 = [on_next(150, 1), on_error(220, ex)]
-        e1 = rx.never()
+        e1 = reactivex.never()
         e2 = scheduler.create_hot_observable(msgs2)
 
         def create():
-            return e1.pipe(
-                ops.zip(e2),
-                ops.map(sum))
+            return e1.pipe(ops.zip(e2), ops.map(sum))
 
         results = scheduler.start(create)
         assert results.messages == [on_error(220, ex)]
 
     def test_zip_error_never(self):
-        ex = 'ex'
+        ex = "ex"
         scheduler = TestScheduler()
         msgs2 = [on_next(150, 1), on_error(220, ex)]
-        e1 = rx.never()
+        e1 = reactivex.never()
         e2 = scheduler.create_hot_observable(msgs2)
 
         def create():
-            return e2.pipe(
-                ops.zip(e1),
-                ops.map(sum))
+            return e2.pipe(ops.zip(e1), ops.map(sum))
 
         results = scheduler.start(create)
         assert results.messages == [on_error(220, ex)]
 
     def test_zip_error_error(self):
-        ex1 = 'ex1'
-        ex2 = 'ex2'
+        ex1 = "ex1"
+        ex2 = "ex2"
         scheduler = TestScheduler()
         msgs1 = [on_next(150, 1), on_error(230, ex1)]
         msgs2 = [on_next(150, 1), on_error(220, ex2)]
@@ -198,15 +207,13 @@ class TestZip(unittest.TestCase):
         e2 = scheduler.create_hot_observable(msgs2)
 
         def create():
-            return e2.pipe(
-                ops.zip(e1),
-                ops.map(sum))
+            return e2.pipe(ops.zip(e1), ops.map(sum))
 
         results = scheduler.start(create)
         assert results.messages == [on_error(220, ex2)]
 
     def test_zip_some_error(self):
-        ex = 'ex'
+        ex = "ex"
         scheduler = TestScheduler()
         msgs1 = [on_next(150, 1), on_next(215, 2), on_completed(230)]
         msgs2 = [on_next(150, 1), on_error(220, ex)]
@@ -214,15 +221,13 @@ class TestZip(unittest.TestCase):
         e2 = scheduler.create_hot_observable(msgs2)
 
         def create():
-            return e1.pipe(
-                ops.zip(e2),
-                ops.map(sum))
+            return e1.pipe(ops.zip(e2), ops.map(sum))
 
         results = scheduler.start(create)
         assert results.messages == [on_error(220, ex)]
 
     def test_zip_error_some(self):
-        ex = 'ex'
+        ex = "ex"
         scheduler = TestScheduler()
         msgs1 = [on_next(150, 1), on_next(215, 2), on_completed(230)]
         msgs2 = [on_next(150, 1), on_error(220, ex)]
@@ -230,9 +235,7 @@ class TestZip(unittest.TestCase):
         e2 = scheduler.create_hot_observable(msgs2)
 
         def create():
-            return e2.pipe(
-                ops.zip(e1),
-                ops.map(sum))
+            return e2.pipe(ops.zip(e1), ops.map(sum))
 
         results = scheduler.start(create)
         assert results.messages == [on_error(220, ex)]
@@ -261,18 +264,18 @@ class TestZip(unittest.TestCase):
         e2 = scheduler.create_hot_observable(msgs2)
 
         def create():
-            return e1.pipe(
-                ops.zip(e2),
-                ops.map(sum))
+            return e1.pipe(ops.zip(e2), ops.map(sum))
 
         results = scheduler.start(create).messages
-        assert (length == len(results))
+        assert length == len(results)
         for i in range(length):
             _sum = msgs1[i].value.value + msgs2[i].value.value
             time = max(msgs1[i].time, msgs2[i].time)
-            assert (results[i].value.kind == 'N'
-                    and results[i].time == time
-                    and results[i].value.value == _sum)
+            assert (
+                results[i].value.kind == "N"
+                and results[i].time == time
+                and results[i].value.value == _sum
+            )
 
     def test_zip_some_data_asymmetric2(self):
         scheduler = TestScheduler()
@@ -299,18 +302,18 @@ class TestZip(unittest.TestCase):
         e2 = scheduler.create_hot_observable(msgs2)
 
         def create():
-            return e1.pipe(
-                ops.zip(e2),
-                ops.map(sum))
+            return e1.pipe(ops.zip(e2), ops.map(sum))
 
         results = scheduler.start(create).messages
-        assert (length == len(results))
+        assert length == len(results)
         for i in range(length):
             _sum = msgs1[i].value.value + msgs2[i].value.value
             time = max(msgs1[i].time, msgs2[i].time)
-            assert (results[i].value.kind == 'N'
-                    and results[i].time == time
-                    and results[i].value.value == _sum)
+            assert (
+                results[i].value.kind == "N"
+                and results[i].time == time
+                and results[i].value.value == _sum
+            )
 
     def test_zip_some_data_symmetric(self):
         scheduler = TestScheduler()
@@ -336,18 +339,18 @@ class TestZip(unittest.TestCase):
         e2 = scheduler.create_hot_observable(msgs2)
 
         def create():
-            return e1.pipe(
-                ops.zip(e2),
-                ops.map(sum))
+            return e1.pipe(ops.zip(e2), ops.map(sum))
 
         results = scheduler.start(create).messages
-        assert (length == len(results))
+        assert length == len(results)
         for i in range(length):
             _sum = msgs1[i].value.value + msgs2[i].value.value
             time = max(msgs1[i].time, msgs2[i].time)
-            assert (results[i].value.kind == 'N'
-                    and results[i].time == time
-                    and results[i].value.value == _sum)
+            assert (
+                results[i].value.kind == "N"
+                and results[i].time == time
+                and results[i].value.value == _sum
+            )
 
     def test_zip_with_iterable_never_empty(self):
         scheduler = TestScheduler()
@@ -355,9 +358,7 @@ class TestZip(unittest.TestCase):
         n2 = []
 
         def create():
-            return n1.pipe(
-                ops.zip_with_iterable(n2),
-                ops.map(sum))
+            return n1.pipe(ops.zip_with_iterable(n2), ops.map(sum))
 
         results = scheduler.start(create)
 
@@ -370,9 +371,7 @@ class TestZip(unittest.TestCase):
         n2 = []
 
         def create():
-            return n1.pipe(
-                ops.zip_with_iterable(n2),
-                ops.map(sum))
+            return n1.pipe(ops.zip_with_iterable(n2), ops.map(sum))
 
         results = scheduler.start(create)
 
@@ -385,9 +384,7 @@ class TestZip(unittest.TestCase):
         n2 = [2]
 
         def create():
-            return n1.pipe(
-                ops.zip_with_iterable(n2),
-                ops.map(sum))
+            return n1.pipe(ops.zip_with_iterable(n2), ops.map(sum))
 
         results = scheduler.start(create)
 
@@ -397,13 +394,12 @@ class TestZip(unittest.TestCase):
     def test_zip_with_iterable_non_empty_empty(self):
         scheduler = TestScheduler()
         n1 = scheduler.create_hot_observable(
-            on_next(150, 1), on_next(215, 2), on_completed(220))
+            on_next(150, 1), on_next(215, 2), on_completed(220)
+        )
         n2 = []
 
         def create():
-            return n1.pipe(
-                ops.zip_with_iterable(n2),
-                ops.map(sum))
+            return n1.pipe(ops.zip_with_iterable(n2), ops.map(sum))
 
         results = scheduler.start(create)
 
@@ -416,9 +412,7 @@ class TestZip(unittest.TestCase):
         n2 = [2]
 
         def create():
-            return n1.pipe(
-                ops.zip_with_iterable(n2),
-                ops.map(sum))
+            return n1.pipe(ops.zip_with_iterable(n2), ops.map(sum))
 
         results = scheduler.start(create)
 
@@ -428,13 +422,12 @@ class TestZip(unittest.TestCase):
     def test_zip_with_iterable_non_empty_non_empty(self):
         scheduler = TestScheduler()
         n1 = scheduler.create_hot_observable(
-            on_next(150, 1), on_next(215, 2), on_completed(230))
+            on_next(150, 1), on_next(215, 2), on_completed(230)
+        )
         n2 = [3]
 
         def create():
-            return n1.pipe(
-                ops.zip_with_iterable(n2),
-                ops.map(sum))
+            return n1.pipe(ops.zip_with_iterable(n2), ops.map(sum))
 
         results = scheduler.start(create)
 
@@ -442,15 +435,13 @@ class TestZip(unittest.TestCase):
         assert n1.subscriptions == [subscribe(200, 230)]
 
     def test_zip_with_iterable_error_empty(self):
-        ex = 'ex'
+        ex = "ex"
         scheduler = TestScheduler()
         n1 = scheduler.create_hot_observable(on_next(150, 1), on_error(220, ex))
         n2 = []
 
         def create():
-            return n1.pipe(
-                ops.zip_with_iterable(n2),
-                ops.map(sum))
+            return n1.pipe(ops.zip_with_iterable(n2), ops.map(sum))
 
         results = scheduler.start(create)
 
@@ -458,15 +449,13 @@ class TestZip(unittest.TestCase):
         assert n1.subscriptions == [subscribe(200, 220)]
 
     def test_zip_with_iterable_error_some(self):
-        ex = 'ex'
+        ex = "ex"
         scheduler = TestScheduler()
         n1 = scheduler.create_hot_observable(on_next(150, 1), on_error(220, ex))
         n2 = [2]
 
         def create():
-            return n1.pipe(
-                ops.zip_with_iterable(n2),
-                ops.map(sum))
+            return n1.pipe(ops.zip_with_iterable(n2), ops.map(sum))
 
         results = scheduler.start(create)
 
@@ -476,17 +465,23 @@ class TestZip(unittest.TestCase):
     def test_zip_with_iterable_some_data_both_sides(self):
         scheduler = TestScheduler()
         n1 = scheduler.create_hot_observable(
-            on_next(150, 1), on_next(210, 2), on_next(220, 3),
-            on_next(230, 4), on_next(240, 5))
+            on_next(150, 1),
+            on_next(210, 2),
+            on_next(220, 3),
+            on_next(230, 4),
+            on_next(240, 5),
+        )
         n2 = [5, 4, 3, 2]
 
         def create():
-            return n1.pipe(
-                ops.zip_with_iterable(n2),
-                ops.map(sum))
+            return n1.pipe(ops.zip_with_iterable(n2), ops.map(sum))
 
         results = scheduler.start(create)
 
-        assert results.messages == [on_next(210, 7), on_next(220, 7),
-                                    on_next(230, 7), on_next(240, 7)]
+        assert results.messages == [
+            on_next(210, 7),
+            on_next(220, 7),
+            on_next(230, 7),
+            on_next(240, 7),
+        ]
         assert n1.subscriptions == [subscribe(200, 1000)]
