@@ -1,21 +1,20 @@
-import pytest
-import unittest
-
 import threading
+import unittest
 from datetime import timedelta
 from time import sleep
 
-from rx.scheduler import CurrentThreadScheduler
-from rx.internal.basic import default_now
+import pytest
+
+from reactivex.internal.basic import default_now
+from reactivex.scheduler import CurrentThreadScheduler
 
 
 class TestCurrentThreadScheduler(unittest.TestCase):
-
     def test_currentthread_singleton(self):
         scheduler = [
             CurrentThreadScheduler(),
             CurrentThreadScheduler.singleton(),
-            CurrentThreadScheduler.singleton()
+            CurrentThreadScheduler.singleton(),
         ]
         assert scheduler[0] is not scheduler[1]
         assert scheduler[1] is scheduler[2]
@@ -108,6 +107,7 @@ class TestCurrentThreadScheduler(unittest.TestCase):
                 ran = True
 
             return scheduler.schedule(inner_action)
+
         scheduler.schedule(action)
 
         assert ran is True
