@@ -1,9 +1,10 @@
 import sys
+
 import pytest
 
-from rx.testing import TestScheduler, ReactiveTest
-from rx.subject import ReplaySubject
-from rx.internal.exceptions import DisposedException
+from reactivex.internal.exceptions import DisposedException
+from reactivex.subject import ReplaySubject
+from reactivex.testing import ReactiveTest, TestScheduler
 
 on_next = ReactiveTest.on_next
 on_completed = ReactiveTest.on_completed
@@ -38,7 +39,7 @@ def test_infinite():
         on_next(710, 9),
         on_next(870, 10),
         on_next(940, 11),
-        on_next(1020, 12)
+        on_next(1020, 12),
     )
 
     subject = [None]
@@ -53,42 +54,52 @@ def test_infinite():
 
     def action1(scheduler, state=None):
         subject[0] = ReplaySubject(3, 100, scheduler)
+
     scheduler.schedule_absolute(100, action1)
 
     def action2(scheduler, state=None):
         subscription[0] = xs.subscribe(subject[0])
+
     scheduler.schedule_absolute(200, action2)
 
     def action3(scheduler, state=None):
         subscription[0].dispose()
+
     scheduler.schedule_absolute(1000, action3)
 
     def action4(scheduler, state=None):
         subscription1[0] = subject[0].subscribe(results1)
+
     scheduler.schedule_absolute(300, action4)
 
     def action5(scheduler, state=None):
         subscription2[0] = subject[0].subscribe(results2)
+
     scheduler.schedule_absolute(400, action5)
 
     def action6(scheduler, state=None):
         subscription3[0] = subject[0].subscribe(results3)
+
     scheduler.schedule_absolute(900, action6)
 
     def action7(scheduler, state=None):
         subscription1[0].dispose()
+
     scheduler.schedule_absolute(600, action7)
 
     def action8(scheduler, state=None):
         subscription2[0].dispose()
+
     scheduler.schedule_absolute(700, action8)
 
     def action9(scheduler, state=None):
         subscription1[0].dispose()
+
     scheduler.schedule_absolute(800, action9)
 
     def action10(scheduler, state=None):
         subscription3[0].dispose()
+
     scheduler.schedule_absolute(950, action10)
 
     scheduler.start()
@@ -98,17 +109,17 @@ def test_infinite():
         on_next(300, 4),
         on_next(340, 5),
         on_next(410, 6),
-        on_next(520, 7)]
+        on_next(520, 7),
+    ]
 
     assert results2.messages == [
         on_next(400, 5),
         on_next(410, 6),
         on_next(520, 7),
-        on_next(630, 8)]
+        on_next(630, 8),
+    ]
 
-    assert results3.messages == [
-        on_next(900, 10),
-        on_next(940, 11)]
+    assert results3.messages == [on_next(900, 10), on_next(940, 11)]
 
 
 def test_infinite2():
@@ -128,7 +139,7 @@ def test_infinite2():
         on_next(710, 9),
         on_next(870, 10),
         on_next(940, 11),
-        on_next(1020, 12)
+        on_next(1020, 12),
     )
 
     subject = [None]
@@ -143,42 +154,52 @@ def test_infinite2():
 
     def action1(scheduler, state=None):
         subject[0] = ReplaySubject(3, 100, scheduler)
+
     scheduler.schedule_absolute(100, action1)
 
     def action2(scheduler, state=None):
         subscription[0] = xs.subscribe(subject[0])
+
     scheduler.schedule_absolute(200, action2)
 
     def action3(scheduler, state=None):
         subscription[0].dispose()
+
     scheduler.schedule_absolute(1000, action3)
 
     def action4(scheduler, state=None):
         subscription1[0] = subject[0].subscribe(results1)
+
     scheduler.schedule_absolute(300, action4)
 
     def action5(scheduler, state=None):
         subscription2[0] = subject[0].subscribe(results2)
+
     scheduler.schedule_absolute(400, action5)
 
     def action6(scheduler, state=None):
         subscription3[0] = subject[0].subscribe(results3)
+
     scheduler.schedule_absolute(900, action6)
 
     def action7(scheduler, state=None):
         subscription1[0].dispose()
+
     scheduler.schedule_absolute(600, action7)
 
     def action8(scheduler, state=None):
         subscription2[0].dispose()
+
     scheduler.schedule_absolute(700, action8)
 
     def action9(scheduler, state=None):
         subscription1[0].dispose()
+
     scheduler.schedule_absolute(800, action9)
 
     def action10(scheduler, state=None):
         subscription3[0].dispose()
+
     scheduler.schedule_absolute(950, action10)
 
     scheduler.start()
@@ -189,17 +210,17 @@ def test_infinite2():
         on_next(300, -2),
         on_next(340, 5),
         on_next(410, 6),
-        on_next(520, 7)]
+        on_next(520, 7),
+    ]
 
     assert results2.messages == [
         on_next(400, 5),
         on_next(410, 6),
         on_next(520, 7),
-        on_next(630, 8)]
+        on_next(630, 8),
+    ]
 
-    assert results3.messages == [
-        on_next(900, 10),
-        on_next(940, 11)]
+    assert results3.messages == [on_next(900, 10), on_next(940, 11)]
 
 
 def test_finite():
@@ -216,7 +237,7 @@ def test_finite():
         on_completed(630),
         on_next(640, 9),
         on_completed(650),
-        on_error(660, 'ex')
+        on_error(660, "ex"),
     )
 
     subject = [None]
@@ -231,42 +252,52 @@ def test_finite():
 
     def action1(scheduler, state=None):
         subject[0] = ReplaySubject(3, 100, scheduler)
+
     scheduler.schedule_absolute(100, action1)
 
     def action3(scheduler, state=None):
         subscription[0] = xs.subscribe(subject[0])
+
     scheduler.schedule_absolute(200, action3)
 
     def action4(scheduler, state=None):
         subscription[0].dispose()
+
     scheduler.schedule_absolute(1000, action4)
 
     def action5(scheduler, state=None):
         subscription1[0] = subject[0].subscribe(results1)
+
     scheduler.schedule_absolute(300, action5)
 
     def action6(scheduler, state=None):
         subscription2[0] = subject[0].subscribe(results2)
+
     scheduler.schedule_absolute(400, action6)
 
     def action7(scheduler, state=None):
         subscription3[0] = subject[0].subscribe(results3)
+
     scheduler.schedule_absolute(900, action7)
 
     def action8(scheduler, state=None):
         subscription1[0].dispose()
+
     scheduler.schedule_absolute(600, action8)
 
     def action9(scheduler, state=None):
         subscription2[0].dispose()
+
     scheduler.schedule_absolute(700, action9)
 
     def action10(scheduler, state=None):
         subscription1[0].dispose()
+
     scheduler.schedule_absolute(800, action10)
 
     def action11(scheduler, state=None):
         subscription3[0].dispose()
+
     scheduler.schedule_absolute(950, action11)
 
     scheduler.start()
@@ -276,22 +307,23 @@ def test_finite():
         on_next(300, 4),
         on_next(340, 5),
         on_next(410, 6),
-        on_next(520, 7)]
+        on_next(520, 7),
+    ]
 
     assert results2.messages == [
         on_next(400, 5),
         on_next(410, 6),
         on_next(520, 7),
-        on_completed(630)]
+        on_completed(630),
+    ]
 
-    assert results3.messages == [
-        on_completed(900)]
+    assert results3.messages == [on_completed(900)]
 
 
 def test_error():
     scheduler = TestScheduler()
 
-    ex = RxException('ex')
+    ex = RxException("ex")
 
     xs = scheduler.create_hot_observable(
         on_next(70, 1),
@@ -304,7 +336,7 @@ def test_error():
         on_error(630, ex),
         on_next(640, 9),
         on_completed(650),
-        on_error(660, RxException('ex'))
+        on_error(660, RxException("ex")),
     )
 
     subject = [None]
@@ -319,42 +351,52 @@ def test_error():
 
     def action1(scheduler, state=None):
         subject[0] = ReplaySubject(3, 100, scheduler)
+
     scheduler.schedule_absolute(100, action1)
 
     def action2(scheduler, state=None):
         subscription[0] = xs.subscribe(subject[0])
+
     scheduler.schedule_absolute(200, action2)
 
     def action3(scheduler, state=None):
         subscription[0].dispose()
+
     scheduler.schedule_absolute(1000, action3)
 
     def action4(scheduler, state=None):
         subscription1[0] = subject[0].subscribe(results1)
+
     scheduler.schedule_absolute(300, action4)
 
     def action5(scheduler, state=None):
         subscription2[0] = subject[0].subscribe(results2)
+
     scheduler.schedule_absolute(400, action5)
 
     def action6(scheduler, state=None):
         subscription3[0] = subject[0].subscribe(results3)
+
     scheduler.schedule_absolute(900, action6)
 
     def action7(scheduler, state=None):
         subscription1[0].dispose()
+
     scheduler.schedule_absolute(600, action7)
 
     def action8(scheduler, state=None):
         subscription2[0].dispose()
+
     scheduler.schedule_absolute(700, action8)
 
     def action9(scheduler, state=None):
         subscription1[0].dispose()
+
     scheduler.schedule_absolute(800, action9)
 
     def action10(scheduler, state=None):
         subscription3[0].dispose()
+
     scheduler.schedule_absolute(950, action10)
 
     scheduler.start()
@@ -364,16 +406,17 @@ def test_error():
         on_next(300, 4),
         on_next(340, 5),
         on_next(410, 6),
-        on_next(520, 7)]
+        on_next(520, 7),
+    ]
 
     assert results2.messages == [
         on_next(400, 5),
         on_next(410, 6),
         on_next(520, 7),
-        on_error(630, ex)]
+        on_error(630, ex),
+    ]
 
-    assert results3.messages == [
-        on_error(900, ex)]
+    assert results3.messages == [on_error(900, ex)]
 
 
 def test_canceled():
@@ -383,7 +426,7 @@ def test_canceled():
         on_completed(630),
         on_next(640, 9),
         on_completed(650),
-        on_error(660, RxException())
+        on_error(660, RxException()),
     )
 
     subject = [None]
@@ -398,53 +441,61 @@ def test_canceled():
 
     def action1(scheduler, state=None):
         subject[0] = ReplaySubject(3, 100, scheduler)
+
     scheduler.schedule_absolute(100, action1)
 
     def action2(scheduler, state=None):
         subscription[0] = xs.subscribe(subject[0])
+
     scheduler.schedule_absolute(200, action2)
 
     def action3(scheduler, state=None):
         subscription[0].dispose()
+
     scheduler.schedule_absolute(1000, action3)
 
     def action4(scheduler, state=None):
         subscription1[0] = subject[0].subscribe(results1)
+
     scheduler.schedule_absolute(300, action4)
 
     def action5(scheduler, state=None):
         subscription2[0] = subject[0].subscribe(results2)
+
     scheduler.schedule_absolute(400, action5)
 
     def action6(scheduler, state=None):
         subscription3[0] = subject[0].subscribe(results3)
+
     scheduler.schedule_absolute(900, action6)
 
     def action7(scheduler, state=None):
         subscription1[0].dispose()
+
     scheduler.schedule_absolute(600, action7)
 
     def action8(scheduler, state=None):
         subscription2[0].dispose()
+
     scheduler.schedule_absolute(700, action8)
 
     def action9(scheduler, state=None):
         subscription1[0].dispose()
+
     scheduler.schedule_absolute(800, action9)
 
     def action10(scheduler, state=None):
         subscription3[0].dispose()
+
     scheduler.schedule_absolute(950, action10)
 
     scheduler.start()
 
     assert results1.messages == []
 
-    assert results2.messages == [
-        on_completed(630)]
+    assert results2.messages == [on_completed(630)]
 
-    assert results3.messages == [
-        on_completed(900)]
+    assert results3.messages == [on_completed(900)]
 
 
 def test_subject_disposed():
@@ -461,64 +512,79 @@ def test_subject_disposed():
 
     def action1(scheduler, state=None):
         subject[0] = ReplaySubject(scheduler=scheduler)
+
     scheduler.schedule_absolute(100, action1)
 
     def action2(scheduler, state=None):
         subscription1[0] = subject[0].subscribe(results1)
+
     scheduler.schedule_absolute(200, action2)
 
     def action3(scheduler, state=None):
         subscription2[0] = subject[0].subscribe(results2)
+
     scheduler.schedule_absolute(300, action3)
 
     def action4(scheduler, state=None):
         subscription3[0] = subject[0].subscribe(results3)
+
     scheduler.schedule_absolute(400, action4)
 
     def action5(scheduler, state=None):
         subscription1[0].dispose()
+
     scheduler.schedule_absolute(500, action5)
 
     def action6(scheduler, state=None):
         subject[0].dispose()
+
     scheduler.schedule_absolute(600, action6)
 
     def action7(scheduler, state=None):
         subscription2[0].dispose()
+
     scheduler.schedule_absolute(700, action7)
 
     def action8(scheduler, state=None):
         subscription3[0].dispose()
+
     scheduler.schedule_absolute(800, action8)
 
     def action9(scheduler, state=None):
         subject[0].on_next(1)
+
     scheduler.schedule_absolute(150, action9)
 
     def action10(scheduler, state=None):
         subject[0].on_next(2)
+
     scheduler.schedule_absolute(250, action10)
 
     def action11(scheduler, state=None):
         subject[0].on_next(3)
+
     scheduler.schedule_absolute(350, action11)
 
     def action12(scheduler, state=None):
         subject[0].on_next(4)
+
     scheduler.schedule_absolute(450, action12)
 
     def action13(scheduler, state=None):
         subject[0].on_next(5)
+
     scheduler.schedule_absolute(550, action13)
 
     def action14(scheduler, state=None):
         with pytest.raises(DisposedException):
             subject[0].on_next(6)
+
     scheduler.schedule_absolute(650, action14)
 
     def action15(scheduler, state=None):
         with pytest.raises(DisposedException):
             subject[0].on_completed()
+
     scheduler.schedule_absolute(750, action15)
 
     def action16(scheduler, state=None):
@@ -539,21 +605,24 @@ def test_subject_disposed():
         on_next(200, 1),
         on_next(250, 2),
         on_next(350, 3),
-        on_next(450, 4)]
+        on_next(450, 4),
+    ]
 
     assert results2.messages == [
         on_next(300, 1),
         on_next(300, 2),
         on_next(350, 3),
         on_next(450, 4),
-        on_next(550, 5)]
+        on_next(550, 5),
+    ]
 
     assert results3.messages == [
         on_next(400, 1),
         on_next(400, 2),
         on_next(400, 3),
         on_next(450, 4),
-        on_next(550, 5)]
+        on_next(550, 5),
+    ]
 
 
 def test_replay_subject_dies_out():
@@ -567,7 +636,7 @@ def test_replay_subject_dies_out():
         on_next(340, 5),
         on_next(410, 6),
         on_next(520, 7),
-        on_completed(580)
+        on_completed(580),
     )
 
     subject = [None]
@@ -579,26 +648,32 @@ def test_replay_subject_dies_out():
 
     def action1(scheduler, state=None):
         subject[0] = ReplaySubject(sys.maxsize, 100, scheduler)
+
     scheduler.schedule_absolute(100, action1)
 
     def action2(scheduler, state=None):
         xs.subscribe(subject[0])
+
     scheduler.schedule_absolute(200, action2)
 
     def action3(scheduler, state=None):
         subject[0].subscribe(results1)
+
     scheduler.schedule_absolute(300, action3)
 
     def action4(scheduler, state=None):
         subject[0].subscribe(results2)
+
     scheduler.schedule_absolute(400, action4)
 
     def action5(scheduler, state=None):
         subject[0].subscribe(results3)
+
     scheduler.schedule_absolute(600, action5)
 
     def action6(scheduler, state=None):
         subject[0].subscribe(results4)
+
     scheduler.schedule_absolute(900, action6)
 
     scheduler.start()
@@ -609,18 +684,16 @@ def test_replay_subject_dies_out():
         on_next(340, 5),
         on_next(410, 6),
         on_next(520, 7),
-        on_completed(580)]
+        on_completed(580),
+    ]
 
     assert results2.messages == [
         on_next(400, 5),
         on_next(410, 6),
         on_next(520, 7),
-        on_completed(580)]
+        on_completed(580),
+    ]
 
-    assert results3.messages == [
-        on_next(600, 7),
-        on_completed(600)]
-
-    assert results4.messages == [
-        on_completed(900)]
+    assert results3.messages == [on_next(600, 7), on_completed(600)]
 
+    assert results4.messages == [on_completed(900)]
